Name:           libdnf5
Version: 5.0.0
Release: 0.20220411084921.4.90+1432.g3a2d123b%{?dist}
Summary:        Package management library
License:        LGPLv2.1+
URL:            https://github.com/rpm-software-management/libdnf
Source0: libdnf-5.0.0-0.20220411084921.4.90+1432.g3a2d123b.tar.xz


# ========== build options ==========

%bcond_without dnfdaemon_client
%bcond_without dnfdaemon_server
%bcond_without libdnf_cli
%bcond_without microdnf
%bcond_without microdnf_plugins
%bcond_without python_plugins_loader

%bcond_without comps
%bcond_without modulemd
%bcond_without zchunk

%bcond_with    html
%if 0%{?rhel} == 8
%bcond_with    man
%else
%bcond_without man
%endif

# TODO Go bindings fail to build, disable for now
%bcond_with    go
%bcond_without perl5
%bcond_without python3
%bcond_without ruby

%bcond_with    clang
%bcond_with    sanitizers
%bcond_without tests
%bcond_with    performance_tests
%bcond_with    dnfdaemon_tests

%if %{with clang}
    %global toolchain clang
%endif

# ========== versions of dependencies ==========

%global libmodulemd_version 2.5.0
%global librepo_version 1.13.0
%global libsolv_version 0.7.7
%global swig_version 4
%global zchunk_version 0.9.11


# ========== build requires ==========

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gettext
%if %{with clang}
BuildRequires:  clang
%else
BuildRequires:  gcc-c++
%endif

BuildRequires:  toml11-devel
BuildRequires:  pkgconfig(check)
%if %{with tests}
BuildRequires:  pkgconfig(cppunit)
%endif
BuildRequires:  pkgconfig(fmt)
BuildRequires:  (pkgconfig(gpgme) or gpgme-devel)
BuildRequires:  pkgconfig(json-c)
%if %{with comps}
BuildRequires:  pkgconfig(libcomps)
%endif
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(librepo) >= %{librepo_version}
BuildRequires:  pkgconfig(libsolv) >= %{libsolv_version}
BuildRequires:  pkgconfig(libsolvext) >= %{libsolv_version}
%if %{with modulemd}
BuildRequires:  pkgconfig(modulemd-2.0) >= %{libmodulemd_version}
%endif
BuildRequires:  pkgconfig(rpm) >= 4.17.0
BuildRequires:  pkgconfig(sqlite3)
%if %{with zchunk}
BuildRequires:  pkgconfig(zck) >= %{zchunk_version}
%endif

%if %{with html} || %{with man}
BuildRequires:  python3dist(breathe)
BuildRequires:  python3dist(sphinx) >= 4.1.2
BuildRequires:  python3dist(sphinx-rtd-theme)
%endif

%if %{with tests}
BuildRequires:  rpm-build
BuildRequires:  createrepo_c
%endif

%if %{with sanitizers}
# compiler-rt is required by sanitizers in clang
BuildRequires:  compiler-rt
BuildRequires:  libasan
BuildRequires:  liblsan
BuildRequires:  libubsan
%endif


# ========== libdnf ==========
#Requires:       libmodulemd{?_isa} >= {libmodulemd_version}
Requires:       libsolv%{?_isa} >= %{libsolv_version}
Requires:       librepo%{?_isa} >= %{librepo_version}

%description
Package management library

%files
%{_libdir}/libdnf.so.*
%license lgpl-2.1.txt
%{_var}/cache/libdnf/

# ========== libdnf-cli ==========

%if %{with libdnf_cli}
%package -n libdnf-cli
Summary:        Library for working with a terminal in a command-line package manager
BuildRequires:  pkgconfig(smartcols)
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n libdnf-cli
Library for working with a terminal in a command-line package manager.

%files -n libdnf-cli
%{_libdir}/libdnf-cli.so.*
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== libdnf-devel ==========

%package -n libdnf5-devel
Summary:        Development files for libdnf
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       libsolv-devel%{?_isa} >= %{libsolv_version}
Conflicts:      libdnf-devel < 5

%description -n libdnf5-devel
Development files for libdnf.

%files -n libdnf5-devel
%{_includedir}/libdnf/
%{_libdir}/libdnf.so
%{_libdir}/pkgconfig/libdnf.pc
%license COPYING.md
%license lgpl-2.1.txt


# ========== libdnf-cli-devel ==========

%package cli-devel
Summary:        Development files for libdnf-cli
Requires:       libdnf-cli%{?_isa} = %{version}-%{release}

%description cli-devel
Development files for libdnf-cli.

%files cli-devel
%{_includedir}/libdnf-cli/
%{_libdir}/libdnf-cli.so
%{_libdir}/pkgconfig/libdnf-cli.pc
%license COPYING.md
%license lgpl-2.1.txt


# ========== perl5-libdnf ==========

%if %{with perl5}
%package -n perl5-libdnf
Summary:        Perl 5 bindings for the libdnf library.
Provides:       perl(libdnf) = %{version}-%{release}
Requires:       %{name}%{?_isa} = %{version}-%{release}
BuildRequires:  perl-devel
BuildRequires:  perl-macros
BuildRequires:  swig >= %{swig_version}
%if %{with tests}
BuildRequires:  perl(strict)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(warnings)
%endif

%description -n perl5-libdnf
Perl 5 bindings for the libdnf library.

%files -n perl5-libdnf
%{perl_vendorarch}/libdnf
%{perl_vendorarch}/auto/libdnf
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== perl5-libdnf-cli ==========

%if %{with perl5} && %{with libdnf_cli}
%package -n perl5-libdnf-cli
Summary:        Perl 5 bindings for the libdnf-cli library.
Provides:       perl(libdnf_cli) = %{version}-%{release}
Requires:       libdnf-cli%{?_isa} = %{version}-%{release}
BuildRequires:  perl-devel
BuildRequires:  perl-macros
BuildRequires:  swig >= %{swig_version}
%if %{with tests}
BuildRequires:  perl(strict)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(warnings)
%endif

%description -n perl5-libdnf-cli
Perl 5 bindings for the libdnf-cli library.

%files -n perl5-libdnf-cli
%{perl_vendorarch}/libdnf_cli
%{perl_vendorarch}/auto/libdnf_cli
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== python3-libdnf ==========

%if %{with python3}
%package -n python3-libdnf5
%{?python_provide:%python_provide python3-libdnf}
Summary:        Python 3 bindings for the libdnf library.
Requires:       %{name}%{?_isa} = %{version}-%{release}
BuildRequires:  python3-devel
BuildRequires:  swig >= %{swig_version}

%description -n python3-libdnf5
Python 3 bindings for the libdnf library.

%files -n python3-libdnf5
%{python3_sitearch}/libdnf5/
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== python3-libdnf-cli ==========

%if %{with python3} && %{with libdnf_cli}
%package -n python3-libdnf-cli
%{?python_provide:%python_provide python3-libdnf-cli}
Summary:        Python 3 bindings for the libdnf-cli library.
Requires:       libdnf-cli%{?_isa} = %{version}-%{release}
BuildRequires:  python3-devel
BuildRequires:  swig >= %{swig_version}

%description -n python3-libdnf-cli
Python 3 bindings for the libdnf-cli library.

%files -n python3-libdnf-cli
%{python3_sitearch}/libdnf_cli/
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== ruby-libdnf ==========

%if %{with ruby}
%package -n ruby-libdnf
Summary:        Ruby bindings for the libdnf library.
Provides:       ruby(libdnf) = %{version}-%{release}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       ruby(release)
BuildRequires:  pkgconfig(ruby)
BuildRequires:  swig >= %{swig_version}
%if %{with tests}
BuildRequires:  rubygem-test-unit
%endif

%description -n ruby-libdnf
Ruby bindings for the libdnf library.

%files -n ruby-libdnf
%{ruby_vendorarchdir}/libdnf/
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== ruby-libdnf-cli ==========

%if %{with ruby} && %{with libdnf_cli}
%package -n ruby-libdnf-cli
Summary:        Ruby bindings for the libdnf-cli library.
Provides:       ruby(libdnf_cli) = %{version}-%{release}
Requires:       libdnf-cli%{?_isa} = %{version}-%{release}
BuildRequires:  pkgconfig(ruby)
BuildRequires:  swig >= %{swig_version}
%if %{with tests}
BuildRequires:  rubygem-test-unit
%endif

%description -n ruby-libdnf-cli
Ruby bindings for the libdnf-cli library.

%files -n ruby-libdnf-cli
%{ruby_vendorarchdir}/libdnf_cli/
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== libdnf-plugin-python-plugins-loader ==========

%if %{with python_plugins_loader}
%package -n python3-libdnf-python-plugins-loader
Summary:        Libdnf plugin that allows loading Python plugins
License:        LGPLv2.1+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python3-libdnf5%{?_isa} = %{version}-%{release}

%description -n python3-libdnf-python-plugins-loader
Libdnf plugin that allows loading Python plugins

%files -n python3-libdnf-python-plugins-loader
%{_libdir}/libdnf-plugins/python_plugins_loader.*
%{python3_sitelib}/libdnf_plugins/
%{python3_sitelib}/libdnf_plugins/README
%endif


# ========== dnfdaemon-client ==========

%if %{with dnfdaemon_client}
%package -n dnfdaemon-client
Summary:        Command-line interface for dnfdaemon-server
License:        GPLv2+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       libdnf-cli%{?_isa} = %{version}-%{release}
Requires:       dnfdaemon-server

%description -n dnfdaemon-client
Command-line interface for dnfdaemon-server

%files -n dnfdaemon-client
%{_bindir}/dnfdaemon-client
%license COPYING.md
%license gpl-2.0.txt
%{_mandir}/man8/dnfdaemon-client.8.gz
%endif


# ========== dnfdaemon-server ==========

%if %{with dnfdaemon_server}
%package -n dnfdaemon-server
Summary:        Package management service with a DBus interface
License:        GPLv2+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       libdnf-cli%{?_isa} = %{version}-%{release}
Requires:       dnf-data
%{?systemd_requires}
BuildRequires:  pkgconfig(sdbus-c++) >= 0.8.1
BuildRequires:  systemd-rpm-macros
%if %{with dnfdaemon_tests}
BuildRequires:  dbus-daemon
BuildRequires:  polkit
BuildRequires:  python3-devel
BuildRequires:  python3dist(dbus-python)
%endif

%description -n dnfdaemon-server
Package management service with a DBus interface

%post -n dnfdaemon-server
%systemd_post dnfdaemon-server.service

%preun -n dnfdaemon-server
%systemd_preun dnfdaemon-server.service

%postun -n dnfdaemon-server
%systemd_postun_with_restart dnfdaemon-server.service

%files -n dnfdaemon-server
%{_bindir}/dnfdaemon-server
%{_unitdir}/dnfdaemon-server.service
%{_sysconfdir}/dbus-1/system.d/org.rpm.dnf.v0.conf
%{_datadir}/dbus-1/system-services/org.rpm.dnf.v0.service
%{_datadir}/dbus-1/interfaces/org.rpm.dnf.v0.*.xml
%{_datadir}/polkit-1/actions/org.rpm.dnf.v0.policy
%license COPYING.md
%license gpl-2.0.txt
%{_mandir}/man8/dnfdaemon-server.8.gz
%{_mandir}/man8/dnfdaemon-dbus-api.8.gz
%endif


# ========== microdnf ==========

%if %{with microdnf}
%package -n microdnf5
Summary:        Command-line package manager
License:        GPLv2+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       libdnf-cli%{?_isa} = %{version}-%{release}
Requires:       dnf-data
Recommends:     bash-completion
BuildRequires:  bash-completion
BuildRequires:  sed

%description -n microdnf5
Microdnf is a command-line package manager that automates the process of installing,
upgrading, configuring, and removing computer programs in a consistent manner.
It supports RPM packages, modulemd modules, and comps groups & environments.

%files -n microdnf5
%{_bindir}/microdnf5
%dir %{_libdir}/microdnf5/
%dir %{_libdir}/microdnf5/plugins/
%{_libdir}/microdnf5/plugins/README
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/microdnf5
%license COPYING.md
%license gpl-2.0.txt
%{_mandir}/man8/microdnf5.8.gz
%endif


# ========== microdnf-plugins ==========

%if %{with microdnf_plugins}
%package -n microdnf5-plugins
Summary:        microdnf plugins
License:        LGPLv2.1+
Requires:       microdnf5%{?_isa} = %{version}-%{release}

%description -n microdnf5-plugins
Microdnf plugins

%files -n microdnf5-plugins
%{_libdir}/microdnf5/plugins/*.so
%endif


# ========== unpack, build, check & install ==========

%prep
%autosetup -p1 -n libdnf-%{version} -n libdnf-5.0.0-0.20220411084921.4.90+1432.g3a2d123b


%build
%cmake \
    -DPACKAGE_VERSION=%{version} \
    -DPERL_INSTALLDIRS=vendor \
    \
    -DWITH_DNFDAEMON_CLIENT=%{?with_dnfdaemon_client:ON}%{!?with_dnfdaemon_client:OFF} \
    -DWITH_DNFDAEMON_SERVER=%{?with_dnfdaemon_server:ON}%{!?with_dnfdaemon_server:OFF} \
    -DWITH_LIBDNF_CLI=%{?with_libdnf_cli:ON}%{!?with_libdnf_cli:OFF} \
    -DWITH_MICRODNF=%{?with_microdnf:ON}%{!?with_microdnf:OFF} \
    -DWITH_PYTHON_PLUGINS_LOADER=%{?with_python_plugins_loader:ON}%{!?with_python_plugins_loader:OFF} \
    \
    -DWITH_COMPS=%{?with_comps:ON}%{!?with_comps:OFF} \
    -DWITH_MODULEMD=%{?with_modulemd:ON}%{!?with_modulemd:OFF} \
    -DWITH_ZCHUNK=%{?with_zchunk:ON}%{!?with_zchunk:OFF} \
    \
    -DWITH_HTML=%{?with_html:ON}%{!?with_html:OFF} \
    -DWITH_MAN=%{?with_man:ON}%{!?with_man:OFF} \
    \
    -DWITH_GO=%{?with_go:ON}%{!?with_go:OFF} \
    -DWITH_PERL5=%{?with_perl5:ON}%{!?with_perl5:OFF} \
    -DWITH_PYTHON3=%{?with_python3:ON}%{!?with_python3:OFF} \
    -DWITH_RUBY=%{?with_ruby:ON}%{!?with_ruby:OFF} \
    \
    -DWITH_SANITIZERS=%{?with_sanitizers:ON}%{!?with_sanitizers:OFF} \
    -DWITH_TESTS=%{?with_tests:ON}%{!?with_tests:OFF} \
    -DWITH_PERFORMANCE_TESTS=%{?with_performance_tests:ON}%{!?with_performance_tests:OFF} \
    -DWITH_DNFDAEMON_TESTS=%{?with_dnfdaemon_tests:ON}%{!?with_dnfdaemon_tests:OFF}
%cmake_build
%if %{with man}
    %cmake_build --target doc-man
%endif


%check
%if %{with tests}
    %ctest
%endif


%install
%cmake_install

# HACK: temporarily rename libdnf to ensure parallel installability with old libdnf
mv $RPM_BUILD_ROOT/%{python3_sitearch}/libdnf $RPM_BUILD_ROOT/%{python3_sitearch}/libdnf5

# HACK: temporarily rename microdnf to ensure parallel installability with old microdnf
mv $RPM_BUILD_ROOT/%{_bindir}/microdnf $RPM_BUILD_ROOT/%{_bindir}/microdnf5
mv $RPM_BUILD_ROOT/%{_mandir}/man8/microdnf.8 $RPM_BUILD_ROOT/%{_mandir}/man8/microdnf5.8
mv $RPM_BUILD_ROOT/%{_datadir}/bash-completion/completions/microdnf $RPM_BUILD_ROOT/%{_datadir}/bash-completion/completions/microdnf5
sed -i 's/microdnf/microdnf5/g' $RPM_BUILD_ROOT/%{_datadir}/bash-completion/completions/microdnf5


#find_lang {name}


%ldconfig_scriptlets


%changelog
* Mon Apr 11 2022 rpm-gitoverlay - 5.0.0-0.20220411084921.4.90+1432.g3a2d123b
- [3a2d123b] Pass widgets by reference (Aleš Matěj)
- [b2d848e6] Add a missing vector include (Aleš Matěj)
- [426c6d1c] test/tutorial/test_tutorial: Set cachedir for all tutorials that load a repo (Lukáš Hrázký)
- [57048392] Use repository cache API and support for "expired" cache attribute (Jaroslav Rohel)
- [6c64684a] repo::RepoCache: API for repository cache (Jaroslav Rohel)
- [45a9b3c0] Cache solvable files in "solv" subdirectory (Jaroslav Rohel)
- [a1881cea] dnfdaemon: Document key confirmation interface (Marek Blaha)
- [dedac689] dnfdaemon: Consistently use uint64_t in repository callbacks (Marek Blaha)
- [c01d8ec4] dnfdaemon-client: Add timeout to repo.list call (Marek Blaha)
- [db48c57d] dnfdaemon: Move repo signals to repo interface (Marek Blaha)
- [76080a5f] dnfdaemon-client: Repository key import confirmation (Marek Blaha)
- [c02d8027] dnfdaemon-client: Add context reference to callbacks (Marek Blaha)
- [17d99b3e] dnfdaemon: Repository key import confirmation (Marek Blaha)
- [4b030356] [MINOR] Change usage of libsolv flags without changing results (Jaroslav Mracek)
- [5ff899d0] Install and add "/var/cache/libdnf" directory to package (Jaroslav Rohel)
- [808ea924] Use cache directory "/var/cache/libdnf" instead of "/var/cache/dnf" (Jaroslav Rohel)
- [788d860d] Fix performance problem with file patterns (Jaroslav Mracek)
- [d3371dd9] Save ".solv" and ".solvx" files to repository cache directory (Jaroslav Rohel)
- [111e1250] microdnf-plugin: "changelog" command plugin (Jaroslav Rohel)
- [7600644b] microdnf: loading of plugins (Jaroslav Rohel)
- [befe09bb] microdnf: Support for loading plugins from .so libraries (Jaroslav Rohel)
- [8646ae2f] Add microdnf5-plugins package (Jaroslav Rohel)
- [79dc1467] microdnf: Add "${CMAKE_INSTALL_FULL_LIBDIR}/microdnf5/plugins" dir with README (Jaroslav Rohel)
- [a958af56] microdnf: Enable symbol export (Jaroslav Rohel)
- [65c730b8] microdnf: IPlugin class - plugins interface, microdnf-plugins subdirectory (Jaroslav Rohel)
- [2405af2e] microdnf: Directory for public headers, make context.hpp public (Jaroslav Rohel)
- [bc6aedb2] microdnf: utils: Remove dead code - implementation moved to libdnf some time ago (Jaroslav Rohel)
- [7471071f] microdnf: Ignore argument parsing errors after "--help" (Jaroslav Rohel)
- [880d1df5] microdnf: Implement "swap" command (Jaroslav Rohel)
- [2540fe3b] libdnf/repo/solv_repo: Properly write comps solvables to libsolv cache (Lukáš Hrázký)
- [c296e6d2] libdnf/repo/solv_repo: Use repowriter for writing main cache (Lukáš Hrázký)
- [922d9395] libdnf/repo/solv_repo: Use repowriter for writing updateinfo cache (Lukáš Hrázký)
- [418a4502] Store rpm database cookie before/after transaction to history db (as DNF4) (Jaroslav Rohel)
- [bd3062b8] rpm::Transaction::get_db_cookie: Retrieve rpm database cookie (Jaroslav Rohel)
- [229ef79b] microdnf: argcomplete: Skip hidden paths if they are not requested (Jaroslav Rohel)
- [9df305bc] microdnf: argcomplete: filter directories to complete (Jaroslav Rohel)
- [81272541] ArgumentParser: Don't add space to end while completing positional arg (Jaroslav Rohel)
- [b7bca76e] microdnf: `match_specs` instead `match_installed_pkgs`,`match_available_pkgs` (Jaroslav Rohel)
- [c74f4cd9] microdnf: complete "keys_to_match" argument in repoquery (Jaroslav Rohel)
- [febdb569] microdnf: Offers paths to rpm files when completing available pkgs (Jaroslav Rohel)
- [49b34b18] microdnf: Fix: match_installed_pkgs: do not offer excluded packages (Jaroslav Rohel)
- [c98ab763] microdnf: Fix: match_installed_pkgs: add missing call `base.setup()` (Jaroslav Rohel)
- [d1398409] test: Fix the add_test() cmake command (Lukáš Hrázký)
- [340bb363] libdnf/utils/fs/temp: Add release() method to TempDir (Lukáš Hrázký)
- [1aca2161] test/libdnf/run_tests: Support specifying test path to run as argument (Lukáš Hrázký)
- [dd8853f0] microdnf: repoquery: support rpm files (cmdline repo) (Jaroslav Rohel)
- [4e223787] microdnf: install,upgrade,downgrade,reinstall from file (cmdline repo) (Jaroslav Rohel)
- [43e5e59c] microdnf: `parse_add_spec` and `Context::add_cmdline_packages` (Jaroslav Rohel)
- [43b82d4f] Package::get_package_path: Return original location for cmdline packages (Jaroslav Rohel)
- [7d661353] rpm::Package: Add `is_excluded` method (Jaroslav Rohel)
- [7d047f90] rpm::PackageSack::Impl::make_provides_ready: Ignore considered map (Jaroslav Rohel)
- [04f79b18] solv::Pool: `swap_considered_map` method (Jaroslav Rohel)
- [9af19124] Fix: Goal::resolve: Call `recompute_considered_in_pool` to apply excludes (Jaroslav Rohel)
- [f4c02318] libdnf/repo/repo_gpgme: Replace low-level functions with std::filesystem (Lukáš Hrázký)
- [851c2e1e] Clean up log messages throughout codebase (Lukáš Hrázký)
- [8547a4e5] test/libdnf/repo: Add test for a non-existent repository (Lukáš Hrázký)
- [e4270def] libdnf/repo: Make Repo::add_rpm_package public (Lukáš Hrázký)
- [dfac9319] libdnf/repo: Remove pimpl (Lukáš Hrázký)
- [dd0edc02] libdnf/repo: Create SolvRepo only when loading or adding a package (Lukáš Hrázký)
- [82972b95] libdnf/repo: Put RepoWeakPtr into a separate header (Lukáš Hrázký)
- [41515604] libdnf/repo: Move get_metadata_path() to RepoDownloader (Lukáš Hrázký)
- [36b49a36] libdnf/repo/repo: Small fixes in get_metadata_path() (Lukáš Hrázký)
- [39ebc736] libdnf/repo/repo_downloader: Load all download outputs in RepoDownloader (Lukáš Hrázký)
- [2d3c23a7] libdnf/repo/repo: Remove owner from Impl (Lukáš Hrázký)
- [2bed654b] libdnf/repo/repo_sack: Remove repo ID verification (Lukáš Hrázký)
- [13d62fa0] libdnf/repo/solv_repo: Drop re-loading written solv cache files (Lukáš Hrázký)
- [3628a194] libdnf/repo/solv_repo: Throw SolvError on load_system_repo() error (Lukáš Hrázký)
- [60ebf109] libdnf/repo/solv_repo: Fix error messages (Lukáš Hrázký)
- [dacbd8d5] libdnf/repo/solv_repo: Move write_* methods to private (Lukáš Hrázký)
- [f60b0619] libdnf/repo/solv_repo: Use RepoDownloader::MD_FILENAME_* constants, improve logging (Lukáš Hrázký)
- [988711ac] libdnf/repo: Generic cleanups of logging messages (Lukáš Hrázký)
- [62f9f95f] libdnf/repo/repo_sack: Check for reposdir existence instead of ignoring errors (Lukáš Hrázký)
- [99ca85b5] libdnf/logger: Modify log calls to transparently format (Lukáš Hrázký)
- [10cf2afd] [dnfdaemon] add tests for distrosync (Nicola Sella)
- [3d21d1c9] RepoSack::update_and_load_repos: More readable exception handling (Jaroslav Rohel)
- [1d14ae66] comps: Add a TODO item for the get_repos method (Pavla Kratochvilova)
- [79e51d80] comps: Sort group_ids and environment_ids by the source repoid (Pavla Kratochvilova)
- [c996d8fd] comps: Improve query costructors to create map only for available groups (Pavla Kratochvilova)
- [e2448a2f] comps: Add fuction to split solvable name into a type:id pair (Pavla Kratochvilova)
- [776809ce] comps: Add function get_translated_str to handle all comps translations (Pavla Kratochvilova)
- [053e1a34] comps: Test that group/environment contains only relevant solvables (Pavla Kratochvilova)
- [6b9bbaed] comps: Support for environments (Pavla Kratochvilova)
- [bc8afeb7] comps: Add tests for GroupQuery filtering (Pavla Kratochvilova)
- [4acbb42d] comps: Add equality operators for groups and change conparison (Pavla Kratochvilova)
- [422a8e13] comps: Fix docstrings, add missing and make @replaces only a comment (Pavla Kratochvilova)
- [bca2a066] comps: Add XMLSaveError to be used when failed to save xml document (Pavla Kratochvilova)
- [65684053] comps: Replace GroupSackWeakPtr with BaseWeakPtr in GroupQuery (Pavla Kratochvilova)
- [0df7f07b] comps: Minor fixes - remove unnecessary variables, fix includes (Pavla Kratochvilova)
- [44bc1d4b] comps: Simplify filtering in group list and info commands (Pavla Kratochvilova)
- [bf7c9b12] comps: Don't expose libsolv ids of groups on the interface (Pavla Kratochvilova)
- [473452d5] dnfdaemon: Avoid duplicite call of base->setup() (Marek Blaha)
- [a1823f05] dnfdaemon: Adapt transaction tests to changed Goal.resolve() (Marek Blaha)
- [8d7614c7] dnfdaemon-client: Apply the changes of resolve() method (Marek Blaha)
- [7b902aa1] dnfdaemon: Rework Goal.resolve() return values (Marek Blaha)
- [cfb76b74] dnfdaemon: Apply session locale to method handlers (Marek Blaha)
- [d8f15cbc] dnfdaemon: Threads manager sets client locale for method handler (Marek Blaha)
- [51b4f0cf] dnfdaemon: Locale configuration per session (Marek Blaha)
- [e05e0bb0] dnfdaemon-client: Pass locale settings to dnfdaemon-server (Marek Blaha)
- [e95abb62] Fix Transaction::Impl copy constructor (Marek Blaha)
- [139891e0] Make SolverProblems::get_problems() method const (Marek Blaha)
- [dda27b95] Make LogEvent::to_string() const method (Marek Blaha)
- [ef2a1593] Goal: unit tests: reinstall, upgrade, downgrade from cmdline (Jaroslav Rohel)
- [c1e988a5] Goal: add_rpm_reinstall, add_rpm_downgrade for rpm::Package (Jaroslav Rohel)
- [d6a689b2] Fix: Goal::Impl::add_rpms_to_goal: do not change value of `rpm_ids` (Jaroslav Rohel)
- [00761c21] Remove solver_problem from transaction class (Jaroslav Mracek)
- [4e088590] Add support of solver problems in resolve_log (Jaroslav Mracek)
- [4791e7d1] Exclude or include source packages (Jaroslav Mracek)
- [b86d3cc7] Add --exclude option (Jaroslav Mracek)
- [1ee45db2] doc/tutorial: Remove the depsolve tutorial stub (Lukáš Hrázký)
- [977884df] doc/tutorial: Add running a transaction tutorial (Lukáš Hrázký)
- [842569f9] libdnf/system/state: Fix state directory path (Lukáš Hrázký)
- [e9474d09] libdnf/base: Put system state into base and construct after installroot is set (Lukáš Hrázký)
- [775fe18a] doc/tutorial: Add tutorial for querying packages (Lukáš Hrázký)
- [ec4d5144] doc/tutorial: Add load_system_repos tutorial (Lukáš Hrázký)
- [8a5506f9] test/tutorial: Improve the tutorials (Lukáš Hrázký)
- [b59dae5d] libdnf/base/transaction: Update Transaction::run() documentation and interface (Lukáš Hrázký)
- [a3373571] [microdnf] implement distro-sync command (Nicola Sella)
- [dd3a6347] rpm::Transaction: Handle new librpm `rpmElementType::TR_RESTORED` (Jaroslav Rohel)
- [00c490c2] CI: Add Fedora 36 to Package Build (Lukáš Hrázký)
- [133b5998] Workaround false-positive GCC -Wrestrict error (Lukáš Hrázký)
- [6499b69e] test/libdnf/comps/test_group: Use utils::fs::File instead of fstream (Lukáš Hrázký)
- [2ba95065] libdnf/utils/iniparser: Use utils::fs::File instead of streams (Lukáš Hrázký)
- [eea7d563] libdnf/system/state: Use utils::fs::File instead of fstream (Lukáš Hrázký)
- [295c7420] libdnf/repo/repo_downloader: Use utils::fs::File instead of ofstream (Lukáš Hrázký)
- [de3253e6] libdnf/conf/vars: Use utils::fs::File instead of ifstream (Lukáš Hrázký)
- [628cc438] libdnf/conf/config_parser: Use utils::fs::File instead of fstreams (Lukáš Hrázký)
- [c9ac7fcf] libdnf/conf/config_main: Use utils::fs::File instead of ifstream (Lukáš Hrázký)
- [405a7460] libdnf/repo/solv_repo: Share code for cache file loading (Lukáš Hrázký)
- [44c4f973] libdnf/repo/solv_repo: Use the File class for working with repo files (Lukáš Hrázký)
- [de591ac1] libdnf/utils/fs/file: Use solv_xfopen() for opening files (Lukáš Hrázký)
- [7496a69b] libdnf/utils/fs: Add File, a FILE * wrapper (Lukáš Hrázký)
- [f01732a8] test/libdnf/fs: Add tests for TempFile (Lukáš Hrázký)
- [77716feb] test/libdnf/fs: Add tests for TempDir (Lukáš Hrázký)
- [a42cc989] libdnf/utils/fs/temp: Fix declaration of TempFile copy constructor (Lukáš Hrázký)
- [ae453de2] libdnf/utils: Move filesystem-related modules to utils/fs (Lukáš Hrázký)
- [217d471f] libdnf: Remove utils::fs::makedirs_for_file() (Lukáš Hrázký)
- [d7c8d328] [dnfdaemon-client] add distro-sync command (Nicola Sella)
- [0ba19b0d] Implement Package.get_source_name() method (Jaroslav Rohel)
- [72df8c04] dnfdaemon: Use standard libdnf method to load repositories (Marek Blaha)
- [e8f3e5ee] dnfdaemon: Implement changelogs package attribute (Marek Blaha)
- [bcb5208c] Implement Package.get_changelogs() method (Marek Blaha)
- [741bccdb] Modify query filters to return `void` (Jaroslav Rohel)
- [d51acff9] Fix use of filters in microdnf advisory command (Jaroslav Rohel)
- [51670e71] .github/workflows/clang-format: Do a rebase before clang-format run (Lukáš Hrázký)
- [c595a711] libdnf/comps/package: Add equality operators and compare vectors in tests (Lukáš Hrázký)
- [133f4545] test/libdnf/comps/test_group: libdnf::comps namespace and initializer lists (Lukáš Hrázký)
- [e97231fb] test: Compare Advisories in AdvisorySets directly instead of using strings (Lukáš Hrázký)
- [3e42511a] test: Compare Packages in PackageSets directly instead of using strings (Lukáš Hrázký)
- [b2bf53b7] test: Assert Reldeps directly instead of converting to string (Lukáš Hrázký)
- [5236b819] libdnf/rpm/reldep: Make to_string() const (Lukáš Hrázký)
- [6e357a42] Use cppunit structures for converting packages to strings (Lukáš Hrázký)
- [23a67099] libdnf/adivsory/advisory: clang-format fix (Lukáš Hrázký)
- [d22476c1] dnfdaemon: Implement package.files attribute (Marek Blaha)
- [1e1d6268] dnfdaemon: Implement ReldepList package attributes (Marek Blaha)
- [a22728c4] libdnf/advisory/advisory: Fix operator!= (Lukáš Hrázký)
- [2bf5392a] Do not build cache for commandline and system repos (Marek Blaha)
- [c38fe0f2] Make build_cache global option defaulting to true (Marek Blaha)
- [bd1763ec] test/libdnf/base_test_case: Drop the cache dir cache (Lukáš Hrázký)
- [11d20e37] libdnf/rpm/transaction: Pass callbacks via unique_ptr (Lukáš Hrázký)
- [d5132bca] libdnf/repo/package_downloader: Pass callbacks via unique_ptr (Lukáš Hrázký)
- [e62b9ee1] bindings: Add repo callbacks for python and ruby, tests (Lukáš Hrázký)
- [a439eb21] test/libdnf/repo: Add tests for repo callbacks (Lukáš Hrázký)
- [3d5f561d] test/libdnf/repo: Use BaseTestCase for RepoTest (Lukáš Hrázký)
- [71d0c966] test/perl5/libdnf: Use CMAKE_SOURCE_DIR instead of a relative path for test data (Lukáš Hrázký)
- [3beb945a] test/ruby/libdnf: Cleanups, use BaseTestCase for TestRepo (Lukáš Hrázký)
- [0295feec] test/python3/libdnf: Cleanups, use BaseTestCase for TestRepo (Lukáš Hrázký)
- [bd9033dc] test/libdnf: unify word serparation on test_case_fixture (Lukáš Hrázký)
- [8f9dae58] test/libdnf: Rename support to base_test_case and sync the name of the class (Lukáš Hrázký)
- [79ee3212] test/ruby/libdnf: Move support/support.rb to base_test_case.rb (Lukáš Hrázký)
- [d135f339] test/python3/libdnf: Move support/support.py to base_test_case.py (Lukáš Hrázký)
- [2862a9d0] libdnf/repo/package_downloader: Add deleter for LrPackageTarget (Lukáš Hrázký)
- [88b20d05] microdnf, dnfdaemon-server: Use is_inbound to determine packages to download (Lukáš Hrázký)
- [17f621c6] libdnf/transaction: Rename forward/backward actions to inbound/outbound (Lukáš Hrázký)
- [c1f3eca8] libdnf/transaction: Rename enum to_string methods (Lukáš Hrázký)
- [7a52a661] libdnf/base/transaction: Create lock in INSTALLROOT/run/dnf (Lukáš Hrázký)
- [2a0af895] libdnf/repo/repo_sack: Clean up repo creation methods (Lukáš Hrázký)
- [06ae02e6] libdnf/repo/repo_sack: Move methods for repo loading from microdnf (Lukáš Hrázký)
- [e9e64e8a] libdnf-cli/progressbar/download_progress_bar: Print trailing newline when finished (Lukáš Hrázký)
- [ddb3bedc] libdnf/repo/repo_callbacks: Document RepoCallbacks (Lukáš Hrázký)
- [e87c2c9d] libdnf/repo/repo_downloader: Add error_message to the end() callback (Lukáš Hrázký)
- [e22c157f] Export goal_elements.hpp enums to bindings (Marek Blaha)
- [8f43a94f] comps: Use &&/|| instead of and/or operators (Pavla Kratochvilova)
- [19f2806b] comps: Better comment how translations are searched for (Pavla Kratochvilova)
- [9cab14b1] comps: Fix translation lookup to call it only once (Pavla Kratochvilova)
- [79327431] comps: Add test for merging groups with different set of translations (Pavla Kratochvilova)
- [69031aaa] comps: Get constant references when iterating group packages read-only (Pavla Kratochvilova)
- [8d572bfd] comps: Use solv::Pool::id2solvable to access solvables (Pavla Kratochvilova)
- [d105c91b] Fix moving and copying AdvisoryModule, AdvisoryPackage, SolverProblems (Jaroslav Rohel)
- [4ecb78a3] Unit tests for `ImplPtr` (Jaroslav Rohel)
- [f45420cc] ImplPtr: smart pointer, specialized in class implementation ownership (Jaroslav Rohel)
- [489e4f0b] Fix: variable may be used uninitialized (Jaroslav Rohel)
- [43888bd8] [doc] substitute docbook format with sphinx (Nicola Sella)
- [261745e0] [doc] add sphinx modules to include D-Bus documentation (Nicola Sella)
- [90318426] comps: Remove GroupQueryWeakPtr (Pavla Kratochvilova)
- [cb26f801] comps: Remove Group destructor as it's no longer needed (Pavla Kratochvilova)
- [24bca410] comps: Minor formatting and import fixes (Pavla Kratochvilova)
- [f1684d6b] comps: Remove group-private (Pavla Kratochvilova)
- [f28ba162] comps: Remove GroupSack::Impl and GroupQuery::Impl (Pavla Kratochvilova)
- [296411be] PreserveOrderMap: Rename `MyBidirIterator` to `BidirIterator` (Jaroslav Rohel)
- [68590163] PreserveOrderMap: Add unit tests (Jaroslav Rohel)
- [34d22c9d] PreserveOrderMap: Added iterator to const_iterator conversion (Jaroslav Rohel)
- [bc27f0cc] PreserveOrderMap: add missing `const` in `const_reverse_iterator` (Jaroslav Rohel)
- [c2bc547a] sack::ExcludeFlags: Add USE_DISABLED_REPOSITORIES flag (Jaroslav Rohel)
- [5564cbd3] microdnf: call `setup_excludes_includes` (Jaroslav Rohel)
- [f580abd2] microdnf: Improve loading of repositories (Jaroslav Rohel)
- [081b060f] dnfdaemon: Fix SIGINT/SIGTERM handling (Marek Blaha)
- [c2723fac] disable_excludes: use "*" instead "all", support globs in repo ids (Jaroslav Rohel)
- [f17576e7] rpm::PackageSack: setup_excludes_includes (Jaroslav Rohel)
- [e495307f] rpm::PackageQuery: Move `flags` into implementation class (Jaroslav Rohel)
- [69a02228] rpm::PackageQuery: support excludes and includes (Jaroslav Rohel)
- [fb58e468] Add rpm::PackageSack::Impl::recompute_considered_in_pool method (Jaroslav Rohel)
- [56eb9158] solv::Pool: Add `considered` map support (Jaroslav Rohel)
- [115e6bbf] Add PackageSack::Impl::compute_considered_map (Jaroslav Rohel)
- [613294aa] Add exclude and include maps into package sack (Jaroslav Rohel)
- [6eb02379] Move `InitFlags` definition out of `rpm::Query`, rename, remove `EMPTY` (Jaroslav Rohel)
- [f326b87b] repo::RepoSack: Add "system" and "cmdline" repo to set of repositories (Jaroslav Rohel)
- [30b8ee9c] Add `repo::Repo::get_type` and `repo::RepoQuery::filter_type` methods (Jaroslav Rohel)
- [b176c514] Add `RepoSack::has_cmdline_repo` method; inline `has_system_repo` (Jaroslav Rohel)
- [ec36ee29] rpm::PackageQuery: fix `swap` (Jaroslav Rohel)
- [b0fbee85] Fix: Memory leak in `solv::SolvMap` move assign operator (Jaroslav Rohel)
- [bf7f2926] Fix: Explicitly cast enum arguments to underlaying type in messages (Jaroslav Rohel)
- [257798c2] test/python3/libdnf/comps/test_group: Update comps loading (Lukáš Hrázký)
- [b6924ef7] test/libdnf/comps/test_group: Use the test fixture temp dir (Lukáš Hrázký)
- [9444cd0c] test/data/repos-repomd: Udate repomd-comps-standard with dumped xml (Lukáš Hrázký)
- [7e8c86db] test/libdnf: Update tests for loading comps (Lukáš Hrázký)
- [7dcee242] Move comps loading to repo (Lukáš Hrázký)
- [018f5f5f] libdnf/comps/group: Dump with indentation and in utf-8 (Lukáš Hrázký)
- [02bf96b5] libdnf/repo: Rename the filenames data type to filelists (Lukáš Hrázký)
- [cde07c76] libdnf/repo/solv_repo: Fix return code check in load_repo_ext() (Lukáš Hrázký)
- [4ecdeefe] test/libdnf: Dump dnf log when a test fails (Lukáš Hrázký)
- [4602240d] test: Copy run_tests.cpp into test/tutorial and test/libdnf-cli (Lukáš Hrázký)
- [0daa9b6f] libdnf/logger: Add StdCStreamLogger for logging to std::cerr and std::cout (Lukáš Hrázký)
- [aeef23f5] libdnf/logger: Use std::chrono::time_point, log in local timezone (Lukáš Hrázký)
- [b7c2156a] libdnf/logger: Add a StringLogger base class (Lukáš Hrázký)
- [6c5c4981] README: Fix link to contributing guidelines (Pavla Kratochvilova)
- [8b4d43ac] doc: Update guide to format includes (Pavla Kratochvilova)
- [09ed026f] output: Highlight incoming packages with epoch/version change (Daniel Mach)
- [6f1e8d58] output: No longer display @System repo of removed/replaced packages (Daniel Mach)
- [d121bd5f] output: Aways print install sizes in the transaction table (Daniel Mach)
- [267d9803] output: Dim replaced packages in the transaction table (Daniel Mach)
- [67c9e42d] sack::match_int64: use libdnf assert, unit tests (Jaroslav Rohel)
- [c92403c2] sack::match_string: implement more comparators, libdnf assert, unit tests (Jaroslav Rohel)
- [434e8bd4] Fix `sack::operator-` for `QueryCmp`; sack::operators as `constexpr` (Jaroslav Rohel)
- [861c6e99] Create centralized point for final setup of Base class (Jaroslav Mracek)
- [8035fc53] advisory::AdvisorySetIterator, rpm::PackageSetIterator: copy assignment (Jaroslav Rohel)
- [47c5c3f7] advisory::AdvisorySet, rpm::PackageSet: similar to MapIterator (Jaroslav Rohel)
- [f6f364a1] Rename `solv::SolvMapIterator` to `solv::ConstMapIterator` (Jaroslav Rohel)
- [672ffd8f] Fix, optimize, and cleanup solv::SolvMap and solv::SolvMapIterator (Jaroslav Rohel)
- [0508c070] solv::SolvMap: remove const_cast; PackageSet, AdvisorySet: fix move ctor (Jaroslav Rohel)
- [ae04870c] solv::SolvMap and SolvMapIterator: Replace pointers by references in API (Jaroslav Rohel)
- [85d38ae0] Fix install location of header files (Daniel Mach)
- [e26fbe74] Error handling in Locker class (Marek Blaha)
- [b921a61e] dnfdaemon: Set dnfdaemon-server stop timeout in systemd (Marek Blaha)
- [31509231] dnfdaemon: Fix unit file name for dbus activation (Marek Blaha)
- [1ced78ab] spec: systemd scriptlets for dnfdaemon-server (Marek Blaha)
- [a1546720] dnfdaemon: Handle SIGINT / SIGTERM (Marek Blaha)
- [5ad488ca] dnfdaemon: Connection as member of SessionManager (Marek Blaha)
- [74197630] Apply clang-format to the codebase (Lukáš Hrázký)
- [8ae3978c] CI: Add a clang-format check to GitHub Actions (Lukáš Hrázký)
- [29f90bbc] New clang-format script to replace clang-format-changed (Lukáš Hrázký)
- [5a383dd7] Switch compiler to C++20 (Jaroslav Rohel)
- [f5397ff4] Use prefix "dep_" with solvable dependencies, compatibility with C++20 (Jaroslav Rohel)
- [74671dbd] Rename local variable `requires` to `dep_requires`, C++20 compatibility (Jaroslav Rohel)
- [6c0e6242] Use `sformat`, where format string is not constant expression, C++20 (Jaroslav Rohel)
- [ef6715a7] Create `sformat`: to format text with non-constant expression (Jaroslav Rohel)
- [dd152664] Log untranslated messages (Jaroslav Rohel)
- [0953a02d] Remove libsolv includes from unit tests (Jaroslav Rohel)
- [31c18e14] Base: Load configuration: Nest exception - add file information (Jaroslav Rohel)
- [5370be8e] Base::unlock: Use libdnf_assert instead of std::logic_error (Jaroslav Rohel)
- [232eb4c1] Exceptions: Sync with new style exceptions, mark messages for translation (Jaroslav Rohel)
- [25ac03f9] exception: format: Fix messages indentation (Jaroslav Rohel)
- [e0f970ea] libdnf: Remove dummy.cpp (Lukáš Hrázký)
- [5ee5fcf9] Replace relative includes with absolute (Lukáš Hrázký)
- [c33fa796] Remove dnf-4 (Lukáš Hrázký)
- [0d2977bc] microdnf: Use libdnf method to run rpm transaction (Marek Blaha)
- [e694c824] dnfdaemon: Use libdnf method to run rpm transaction (Marek Blaha)
- [988c3db5] Transaction::run() method (Marek Blaha)
- [dacc6ed4] Lock files class (Marek Blaha)
- [579e3db9] libdnf/base/solver_problems: Fix includes after changing paths (Lukáš Hrázký)
- [ad16a5af] test: Update include paths to the separated include dirs (Lukáš Hrázký)
- [5a3859c1] microdnf: Switch includes to paths within microdnf (Lukáš Hrázký)
- [3905fbe1] libdnf: Remove utils/span.hpp (Lukáš Hrázký)
- [f1bdb973] dnfdaemon-server: Switch includes to paths within dnfdaemon-server (Lukáš Hrázký)
- [77cf21c0] libdnf-cli: Switch private includes to paths within libdnf-cli (Lukáš Hrázký)
- [9546f7da] Move bgettext and string from libdnf/utils to common (Lukáš Hrázký)
- [b74be22c] libdnf: Switch private includes to paths within libdnf (Lukáš Hrázký)
- [43cb6436] cmake: Don't add top-level directory as include path (Lukáš Hrázký)
- [1edbfa49] libdnf-cli: Move public headers to include/libdnf-cli (Lukáš Hrázký)
- [e72082c6] libdnf-cli: Make tty.hpp a public header, move out of utils (Lukáš Hrázký)
- [4f2d3388] libdnf: Set default cachedir and logdir (Lukáš Hrázký)
- [ccadab07] libdnf/advisory: Implement pimpl for AdvisorySack (Lukáš Hrázký)
- [763e5039] Add missing constructors and remove unneeded operators (Jaroslav Mracek)
- [20b06b83] Rename element in SolverProblems::Impl class (Jaroslav Mracek)
- [031694a0] Rename 2 methods in SolverProblems class (Jaroslav Mracek)
- [945077ea] Move solver problem setting related code to SolverProblems (Jaroslav Mracek)
- [56523956] Add IMPL for SolverProblems (Jaroslav Mracek)
- [c6f592ea] [minor] Add changes generated by clang-format (Jaroslav Mracek)
- [d76d30c6] Move solver error report related code to the new class (Jaroslav Mracek)
- [81e4b858] unittest: Python: Tests for RepoQuery (Jaroslav Rohel)
- [5726a58b] swig: Set: `len` support in Python (Jaroslav Rohel)
- [c385eb13] swig: Basic iter support for Set and RepoQuery, hash for WeakPtr in Python (Jaroslav Rohel)
- [168addc6] unittests: Test iteration over RepoQuery object (Jaroslav Rohel)
- [8c0727e8] Set: Add iterators - SetConstIterator class, with unittests (Jaroslav Rohel)
- [daedaa3c] libsolv/repo: Move system and cmdline repos to RepoSack (Lukáš Hrázký)
- [6d6a359e] libdnf/repo: Move loading of system repo to Repo::load() (Lukáš Hrázký)
- [d8fd2bb1] libdnf/repo: Move loading of available repo from PackageSack to Repo (Lukáš Hrázký)
- [7e4ad8f7] libdnf/repo: Rename Repo metadata loading functions (Lukáš Hrázký)
- [75047b64] libdnf/rpm/package_sack: Drop the unused considered_uptodate flag (Lukáš Hrázký)
- [ab6f1b26] libdnf/rpm/package_sack: Use RepoQuery instead of iterating over libsolv repos (Lukáš Hrázký)
- [b63a8ccc] libdnf/repo: Unify internalizing on using SolvRepo::internalize() (Lukáš Hrázký)
- [311522a9] libdnf/comps: Drop Comps::load_from_file() that creates a new libsolv repo (Lukáš Hrázký)
- [2bb6da39] libdnf/solv/pool: Add a method to get repo from solvable (Lukáš Hrázký)
- [e5cb100d] libdnf/repo: Move PachageSack::rewrite_repos() logic to SolvRepo::rewrite_repo() (Lukáš Hrázký)
- [ec94c8dd] libdnf/repo/solv_repo: Call write_{main,ext} from load_repo_{main,ext} (Lukáš Hrázký)
- [db8824d2] libdnf/repo/solv_repo: Pass RepodataType directly to loading/writing functions (Lukáš Hrázký)
- [b61b8f15] libdnf/repo: Move load_system_repo() from PackageSack to SolvRepo (Lukáš Hrázký)
- [3634599d] libdnf/repo: Move load_repo_main() from PackageSack to SolvRepo (Lukáš Hrázký)
- [f068f246] libdnf/repo: Create libsolv repo in SolvRepo constructor (Lukáš Hrázký)
- [93f24e40] libdnf/repo: Move low-level libsolv repo code from PackageSack to SolvRepo (Lukáš Hrázký)
- [d30a6d62] libdnf/repo: Rename LibsolvRepoExt to SolvRepo and separate it into a module (Lukáš Hrázký)
- [b80788f9] libdnf/repo: Store BaseWeakPtr, clean up Repo constructors (Lukáš Hrázký)
- [d02d9242] test/python3/libdnf: Add a missing repo/__init__.py (Lukáš Hrázký)
- [b8f2b94b] bindings: Fix catching exceptions (Lukáš Hrázký)
- [c955c5a7] plugin: Remove PluginLibrary class from public header (Jaroslav Rohel)
- [67801fd5] AssertionError for "Unsupported sack::QueryCmp value" and different base (Jaroslav Rohel)
- [89fc2e02] Exceptions: use libdnf::RuntimeError, mark messages for translation (Jaroslav Rohel)
- [b7200ae1] Exceptions: format: Add configurable prefix, remove level from API (Jaroslav Rohel)
- [2b5d5b6f] Exceptions: added support for messages localization (Jaroslav Rohel)
- [d9e0e846] Add general `filter_reference` and remove specific bug/cve filters (Aleš Matěj)
- [006e51ee] Add possible types for Advisory and AdvisoryReference (Aleš Matěj)
- [fdc1652c] Move and rename get_sorted_advisory_packages (Aleš Matěj)
- [3d43e33a] Optimize AdvisoryQuery by using libsolv dataiterator for matching (Aleš Matěj)
- [0f183267] Remove ENUMs of Advisory and AdvisoryReference types (Aleš Matěj)
- [6b3e8951] Add notes related to CLI differences between DNF4 and 5 (Jaroslav Mracek)
- [465afc33] b_dmgettext: Strict prefix control before translation (Jaroslav Rohel)
- [d11d887d] Restructure microdnf advisory command to use subcommands (Aleš Matěj)
- [0f4aa931] Add output formatting for advisory list and info into libdnf-cli (Aleš Matěj)
- [cb96de40] Add additional getters to advisories objects (Aleš Matěj)
- [514fe82c] Add lookup_num to Pool class (Aleš Matěj)
- [2f528454] Fix assertion_traits in "test/libdnf/utils.hpp" - C++20 compatibility (Jaroslav Rohel)
- [d49da07a] PreserveOrderMap: Fix reverse iterators (Jaroslav Rohel)
- [6c6f80a4] microdnf: command line: Add compatible aliases to global options (Jaroslav Rohel)
- [f964b403] ArgumentParser: Add public getters (Jaroslav Rohel)
- [434059de] microdnf: command line: Add global group of options (Jaroslav Rohel)
- [152632f2] libdnf/repo: Error handling rework (Lukáš Hrázký)
- [a38fcf04] libdnf/utils/temp: Add a TempFile class (Lukáš Hrázký)
- [3eb809d6] libdnf/utils/temp: Use path as the destdir argument type, change the mkdtemp template arg (Lukáš Hrázký)
- [a4f0a2a6] libdnf/utils/temp: Make TempDir suffix contain the separator dot (Lukáš Hrázký)
- [7ab456a8] libdnf/repo/repo_downloader: Use std::filesystem directory iteration (Lukáš Hrázký)
- [630c026c] libdnf/repo/repo_downloader: Simplify download_metadata() (Lukáš Hrázký)
- [5827ea78] libdnf/utils/temp: Throw std::filesystem::filesystem_error (Lukáš Hrázký)
- [c6a63dbe] libdnf: Rework the error class system (Lukáš Hrázký)
- [49432ace] rpm::Transaction::Impl: Use macro to assert that transaction item is set (Jaroslav Rohel)
- [bf7f5d5e] Rewrite specialized assert functions into macros (Jaroslav Rohel)
- [fd94dcba] Remove PROJECT_SOURCE_DIR prefix from __FILE__ macro used in asserts (Jaroslav Rohel)
- [4dd9a1df] AssertionError: Add information about assertion source location (macros) (Jaroslav Rohel)
- [cee349ea] [dnf5] refactor code dnfdaemon-client: parse then init_session (Nicola Sella)
- [81910072] ArgumentParser: Possibility to disable completion of argument (Jaroslav Rohel)
- [1d1a058c] microdnf: Add "--no-plugins", "--enable-plugin", "--disable-plugin" args (Jaroslav Rohel)
- [7e6d6af7] microdnf: Add "--no-gpgchecks" argument (Jaroslav Rohel)
- [67a89586] microdnf: Add "--enable-repo", "--disable-repo", "--repo" arguments (Jaroslav Rohel)
- [5eb6bdff] microdnf: "--setopt", "--setvar": more accurate argument value description (Jaroslav Rohel)
- [a9260af5] rpm::TransactionCB: rename to rpm::TransactionCallbacks (Jaroslav Rohel)
- [2dfe804d] rpm::TransactionCB: Define and use ScriptType enum (Jaroslav Rohel)
- [9e25e6a8] rpm::TransactionCB: remove rpm::RpmHeader, use rpm::Nevra in script_* (Jaroslav Rohel)
- [270c1bd4] rpm::Package: Constructor from rpmdbid (Jaroslav Rohel)
- [5c2b3108] rpm::Transaction: Use rpmtsNotifyChange callback (Jaroslav Rohel)
- [1103c7e9] rpm::Transaction: Use new librpm transaction notify callback style (Jaroslav Rohel)
- [4cdb9a79] libdnf/common/exception: Replace LogicError with AssertionError (Lukáš Hrázký)
- [19dd1d02] bindings: Undefine conflicting macros from ruby.h (Lukáš Hrázký)
- [12042031] libdnf/solv/pool: Get rid of C asserts (Lukáš Hrázký)
- [2d09b7ee] libdnf/common/exception: Reuse SystemError constructor (Lukáš Hrázký)
- [17002bd2] microdnf: Add "--skip-broken" argument (Jaroslav Rohel)
- [01bb3496] Update advisories tests to reflect the update to `AdvisorySet` (Aleš Matěj)
- [e16d8f11] Use `AdvisorySet` to store data in `AdvisoryQuery` (Aleš Matěj)
- [36bd3070] Change `load_advisories` to `get_solvables` for `AdvisorySack` (Aleš Matěj)
- [ea608e31] Add `AdvisorySet` and its iterator together with unit tests (Aleš Matěj)
- [3e4f1753] Add basic comparison operators to Advisory (Aleš Matěj)
- [74cacd29] advisory: Add unittests for AdvisoryReference (Aleš Matěj)
- [20442cb8] CI: Build only for f35 and higher in Package Build (Lukáš Hrázký)
- [e2a91717] microdnf: Implement 'repo info' command (Daniel Mach)
- [d0982824] output: remove const from RepoInfo.add_repo(const Repo) (Daniel Mach)
- [4972d779] microdnf: Refactor 'repo list' arguments (Daniel Mach)
- [0d4238e3] microdnf: Rename 'repolist' command to 'repo list' (Daniel Mach)
- [b9279ab3] microdnf: Add "--best" and "--no-best" arguments (Jaroslav Rohel)
- [6f7109e5] microdnf: Add "--config" argument (Jaroslav Rohel)
- [f4f83ed8] libdnf-cli: Replace join() function with one from libdnf::utils (Marek Blaha)
- [b5d478de] dnfdaemon-client: Remove unused functions (Marek Blaha)
- [cf16d618] microdnf: Add bash completion script (Jaroslav Rohel)
- [0a318bc6] microdnf: autocomplete packages to install/download on command line (Jaroslav Rohel)
- [a7775660] microdnf: autocomplete pkgs to remove/reinstall/downgrade/upgrade on cmd line (Jaroslav Rohel)
- [f1449f03] microdnf: Command line option "--quiet/-q", quiet mode (Jaroslav Rohel)
- [c573217c] microdnf: set_cache_dir and apply_repository_setopts in Context class (Jaroslav Rohel)
- [e5255e74] ArgumentParser::PositionalArg: Support completion via user hook function (Jaroslav Rohel)
- [66b053dc] ArgumentParser::PositionalArg: Fix: number of arguments to parse_hook_func (Jaroslav Rohel)
- [b6f49967] Replace redundant code by method (Jaroslav Mracek)
- [bf50e95b] Report replaced packages as replaced (Jaroslav Mracek)
- [1d70cfc6] Color differently TSI when obsoleted (Jaroslav Mracek)
- [400afd5b] Replace reverse transaction actions by REPLACED (Jaroslav Mracek)
- [56c38990] Use overlay dedicated for dnf5 when running dnf5 CI (Aleš Matěj)
- [cb4b8665] Run dnfdaemon integration tests as a part of CI (Aleš Matěj)
- [8292a5e4] [dnf5] argparser return 2 on exception (Nicola Sella)
- [c710e7a3] tests: Adjust to changes in GoalProblem enum (Marek Blaha)
- [91277872] microdnf: Help output, prefer to reduce width of description (Jaroslav Rohel)
- [aaf51880] Remove replaced method (Jaroslav Mracek)
- [9f184c2d] Replace resolve log tuple by structure (Jaroslav Mracek)
- [c850f9a3] Remove unneeded attribute (Jaroslav Mracek)
- [80379c5c] Replace REMOVAL_OF_PROTECTED by SOLVER_ERROR (Jaroslav Mracek)
- [f8d7e7d3] tests/libdnf: Add a commented line to disable exception catching in cppunit (Lukáš Hrázký)
- [4b071281] libdnf/repo/gpgme: Clean up error messages (Lukáš Hrázký)
- [b6bf40a3] libdnf/repo/gpgme: Fix context initialization (Lukáš Hrázký)
- [048639ba] libdnf/repo: Separate metadata downloader into its own module (Lukáš Hrázký)
- [77384628] libdnf/repo: Separate gpg code into its own module (Lukáš Hrázký)
- [01983abf] libdnf/repo: Move get_cachedir() and get_persistdir() to ConfigRepo (Lukáš Hrázký)
- [757b5cd5] libdnf/repo: Store repo id in ConfigRepo (Lukáš Hrázký)
- [11dbab42] libdnf/repo: Move RepoCallbacks into its own header (Lukáš Hrázký)
- [e8a6b465] [dnf5] fix dnfdaemon segfault with empty args (Nicola Sella)
- [f0c4f7f2] dnfdaemon-client: implement group list and info commands (Marek Blaha)
- [4a3fe86e] dnfdaemon-client: Refactor Command objects (Marek Blaha)
- [b806e688] libdnf-cli: Turn group list and info tables into templates (Marek Blaha)
- [04a40bee] dnfdaemon-client: Add wrapper class for Groups (Marek Blaha)
- [0f04f322] dnfdaemon: New Group interface (Marek Blaha)
- [c725cfa7] dnfdaemon: Implement missing package attributes (Marek Blaha)
- [1bd63f00] libdnf/repo: Move package downloading code into the PackageDownloader class (Lukáš Hrázký)
- [fb67acb3] libdnf/repo: Simplify logic in lr_handle_perform() (Lukáš Hrázký)
- [458d4566] libdnf/repo: Move generic remote handle setup to new_remote_handle() (Lukáš Hrázký)
- [1a66dbd2] libdnf/repo: Clean up Repo::Impl::lr_handle_init_* (Lukáš Hrázký)
- [1d2d29da] libdnf/repo: Share code for creating LrHandle (Lukáš Hrázký)
- [f03f7992] Use TempDir in Repo downloading code (Lukáš Hrázký)
- [7a61ab54] utils: Clean up The TempDir class (Lukáš Hrázký)
- [565bac33] libdnf/advisory: Don't use glib's g_strcmp0() (Lukáš Hrázký)
- [debce7c4] libdnf/repo: Simplify calling download_metadata() (Lukáš Hrázký)
- [711870ef] microdnf: Command line argument completion support (Jaroslav Rohel)
- [a2d4d58a] ArgumentParser: Argument completion support (Jaroslav Rohel)
- [26b0326e] ArgumentParser: Fix headers inclusion, no explicitly call default base ctor (Jaroslav Rohel)
- [11fe3c0e] dnfdaemon: Document Repo interface (Marek Blaha)
- [0f65cd62] dnfdaemon: Document Goal interface (Marek Blaha)
- [b46e8268] [tests] Add new assertResolveErrorsEmpty (Marek Blaha)
- [0db698a1] typo: INSLALLED -> INSTALLED (Marek Blaha)
- [84ffb587] [dnf5] fix GoalAction in documentation comments (Nicola Sella)
- [0ef3c1d0] [dnf5] dnfdaemon exits nicely when transaction is empty (Nicola Sella)
- [58f5ac12] argparse: Avoid printing duplicate ungrouped options in help (Daniel Mach)
- [54b5c1e4] microdnf: Add several compatibility aliases (Daniel Mach)
- [7085cccc] argparse: Refactor help to use class wrappers for usage and args (Daniel Mach)
- [984784bd] libdnf-cli: define GETTEXT_DOMAIN (Daniel Mach)
- [5aad5d76] argparse: Generate and print usage in help() (Daniel Mach)
- [ab3bcaed] CI: Run on Fedora 35 (Lukáš Hrázký)
- [5fa34c08] CI: Add dnf-nightly repo to the package-build Copr build (Lukáš Hrázký)
- [4972155d] microdnf: Simplify group {list,info} commands by using the new option wrappers (Daniel Mach)
- [450e39aa] microdnf: define GETTEXT_DOMAIN (Daniel Mach)
- [192683b0] cli: Create classes that wrap config and argparse options (Daniel Mach)
- [cda0dc16] microdnf: Move group{info,list} commands under group subcommand (Daniel Mach)
- [0e8533e4] microdnf: Add --minimal option to upgrade, replacing upgrade-minimal command (Daniel Mach)
- [e8381f6b] microdnf: Add stubs of module commands (Daniel Mach)
- [a069363a] microdnf: Add stubs of history commands (Daniel Mach)
- [d6b17de0] argparse: Avoid printing 'Commands:' help section if it's empty (Daniel Mach)
- [7f9eb514] microdnf: Regroup commands in help (Daniel Mach)
- [04bbe8a0] microdnf: Use the default parse hook in commands (Daniel Mach)
- [b4887b82] cli: Automatically set parsed command as selected (Daniel Mach)
- [374f7645] rpm::Transaction: Remove install/upgrade/downgrade/reinstall/erase methods (Jaroslav Rohel)
- [57b9f569] rpm::Transaction: Replace `fill_transaction` by `fill` method and use it (Jaroslav Rohel)
- [830af48e] base::Transaction: "get_packages" to "get_transaction_packages", mark as const (Jaroslav Rohel)
- [5c040bed] rpm::Transaction: Use base::TransactionPackage as TransactionItem (Jaroslav Rohel)
- [e88fbd09] rpm::RpmHeader: Improve memory management of internal rpm header (Jaroslav Rohel)
- [032e0731] rpm::Transaction: Fix memory leak of rpm header (Jaroslav Rohel)
- [850a968c] comps: Revamp groupinfo output (Daniel Mach)
- [6e3b186a] advisory: Clean up constructors and assignment operators (Lukáš Hrázký)
- [568b7d23] microdnf: use command groups (Jaroslav Rohel)
- [45f1d6dd] cli: support commands groups (Jaroslav Rohel)
- [7dddc275] ArgumentParser: Take groups of arguments into account when generating help (Jaroslav Rohel)
- [dd039844] ArgumentParser: Support arguments groups (Jaroslav Rohel)
- [a32851ae] comps: Display both installed and available groups with the same ID (Daniel Mach)
- [18169d6d] comps: Load installed comps into @System repo (Daniel Mach)
- [dc42eaba] Add PackageSack::get_system_repo() method (Daniel Mach)
- [134aa608] comps: Load groups from actual repodata (Daniel Mach)
- [a9c899c8] repo: Refactor load flags (Daniel Mach)
- [6376cc12] cli: Make grouplist output more compact and readable (Daniel Mach)
- [6b4fb55e] comps: Replace custom Pool instance with Pool from the Base (Daniel Mach)
- [b9f9c279] Replace Goal::Action by GoalAction (Jaroslav Mracek)
- [1fa428b4] Fix copy constructor and operator= of GoalPrivate class (Jaroslav Mracek)
- [285e7474] Resolve all goal request goal after resolve() (Jaroslav Mracek)
- [e4a4576d] Move code related to solver problems to Transaction class (Jaroslav Mracek)
- [d5622550] Move rpm transaction log from Goal to Transaction (Jaroslav Mracek)
- [14b6b851] Use the system::State class to store userinstalled reasons (Lukáš Hrázký)
- [1b23360b] Add the libdnf::system::State class (Lukáš Hrázký)
- [f14fdd78] tests: Add add_system_pkg method to RepoFixture and clean up Goal tests (Lukáš Hrázký)
- [eae32217] microdnf: Streamline and de-duplicate code for running the transaction (Lukáš Hrázký)
- [3a384466] Add a Package::get_na() method (Lukáš Hrázký)
- [f944b242] Enhance documentation strings of Goal class (Jaroslav Mracek)
- [d15075df] Replace overloaded methods by methods with a default values (Jaroslav Mracek)
- [8d328c35] [doc] Add or improve documentation strings for Goal class (Jaroslav Mracek)
- [9fed961f] Fix problem with distrosync (Jaroslav Mracek)
- [0897e85c] [dnf5] remove generic catch(...) (Nicola Sella)
- [15ba6784] CI: Run microdnf5 CI stack tests on PRs (Lukáš Hrázký)
- [f99212f8] [dnf5] fix crash when dbus is not running (Nicola Sella)
- [24e02f90] microdnf: Add search command stub (Daniel Mach)
- [26d647fa] microdnf: Add swap command stub (Daniel Mach)
- [f663ac82] microdnf: Add --unneeded option stub to the remove command (Daniel Mach)
- [80d52778] microdnf: Add distro-sync command stub (Daniel Mach)
- [690e17bb] microdnf: Remove redundant opt/arg header descriptions (Daniel Mach)
- [018d935e] microdnf: Improve command short descriptions (Daniel Mach)
- [5ef344b2] microdnf: Inherit Context from Session, use the new Command class (Daniel Mach)
- [e1180b15] cli: Create Session and Command classes (Daniel Mach)
- [8e61fffc] argparse: Better align printed help (Daniel Mach)
- [1e28296b] argparse: Print all available commands, options and arguments by default (Daniel Mach)
- [74130e81] microdnf: Remove unused configure() and pre_configure() (Daniel Mach)
- [063f7a63] cli: Print help of selected command (Daniel Mach)
- [3aede222] argparse: Store the selected command in the argument parser (Daniel Mach)
- [e23f933b] Move libsolv Pool into Base (Lukáš Hrázký)
- [00ff1246] Wrap commonly used pool functions into a Pool class (Lukáš Hrázký)
- [162c86be] test: Don't wrap Base in unique_ptr in LibdnfTestCase (Lukáš Hrázký)
- [ebc86666] test: Performance test for Query::filter_provides (Lukáš Hrázký)
- [db4c13d3] [dnf5] dnfdaemon-client spec requires server (Nicola Sella)
- [c842adfe] [dnf5] missing return after catching exception (Nicola Sella)
- [c2843e94] [dnf5] exit nicely when server is not running (Nicola Sella)
- [ae14fd9b] dnfdaemon: Support for upgrade all packages (Marek Blaha)
- [598fc299] [minor] Remove unneeded argument from a call (Jaroslav Mracek)
- [ed76f0a7] Add support in microdnf to upgrade all without an argument (Jaroslav Mracek)
- [3d8048ad] Fix creation of obsoleted transaction items (Jaroslav Mracek)
- [97aa7dff] doc: Document RepoSet and RepoQuery (Daniel Mach)
- [354275bf] Rename PackageQuery::filter_latest() to filter_latest_evr() (Daniel Mach)
- [70c5c032] Rename PackageQuery::filter_repoid() to filter_repo_id() (Daniel Mach)
- [c709dbd9] Move set operation methods from PackageQuery to PackageSet (Daniel Mach)
- [21d9b082] Fix all license headers (Daniel Mach)
- [ca935769] [dnfdaemon] Exceptions handling in method/signal handlers (Marek Blaha)
- [918bde26] WeakPtr: partial support for multiple threads (Jaroslav Rohel)
- [d6a50ac9] Add new API append_extra_system_repo() function: (Clément Bénier)
- [280cd3fb] tests: Simplify repo loading in ruby unit tests (Daniel Mach)
- [5eee0fc9] tests: Simplify repo loading in python unit tests (Daniel Mach)
- [c0bb1ddf] tests: Simplify test repo loading (Daniel Mach)
- [5e8aeb30] tests: Rename RepoFixture class to LibdnfTestCase (Daniel Mach)
- [fd276c5b] tests: Rename repo_fixture.hpp to support.hpp (Daniel Mach)
- [9d52a2eb] [dnfdaemon] Fix method/signal handling in thread (Marek Blaha)
- [d0be6d50] Move BaseWeakPtr declaration to a special header (Lukáš Hrázký)
- [6437448e] Clean up headers and includes (Lukáš Hrázký)
- [2ec1bed5] [dnf5] dnfdaemon test: remove package_size (Nicola Sella)
- [b4ff0cd0] [dnf5] dnfdaemon: add reinstall command (Nicola Sella)
- [75074ef7] microdnf: Add a global try-catch for RuntimeError (Lukáš Hrázký)
- [ffacfc7b] libdnf-cli: Add an ActionHeaderPrinter class (Lukáš Hrázký)
- [22be666a] libdnf-cli: Print an epmty line before Transaction Summary (Lukáš Hrázký)
- [24482799] Pass TranasctionPackages from Goal and Transaction onwards (Lukáš Hrázký)
- [41daf254] libdnf/base/transaction: Clean up the Transaction(Item)Package class (Lukáš Hrázký)
- [d8c381a8] Goal tests: Add test repo only where relevant (Lukáš Hrázký)
- [f8c2cc91] Move PackageSetIterator impl into .cpp (Lukáš Hrázký)
- [ae0f4301] tests: Add options to RepoFixture::get_pkg, improve error messages (Lukáš Hrázký)
- [1886ec3f] tests: Move the get_pkg() method to RepoFixture (Lukáš Hrázký)
- [b77a44d1] dnfdaemon-client: Check that --installroot is an absolute path (Marek Blaha)
- [239a9c39] dnfdaemon: Add method to handle signal in thread (Marek Blaha)
- [b94ecf16] dnfdaemon: rename run_in_thread -> handle_method (Marek Blaha)
- [c1a3f237] dnfdaemon: Use run_in_threads() also for session operations (Marek Blaha)
- [1a4aad54] tests: Do not explicitly close dbus sessions in tearDown() (Marek Blaha)
- [d330480f] dnfdaemon: move run_in_thread() to ThreadsManager (Marek Blaha)
- [e4071839] dnfdaemon-client: Support for the installroot (Marek Blaha)
- [1034be16] dnfdaemon: Enable setopt for all options (Marek Blaha)
- [054f50a0] dnfdaemon: Adjust tests to changes in resolve() return value (Marek Blaha)
- [4860e201] [minor] Unify style for initiation of objects (Jaroslav Mracek)
- [34a5d783] Set problems in Transaction (Jaroslav Mracek)
- [2e6bf4af] Add TODO to unused transaction action (Jaroslav Mracek)
- [7eaedd64] Preserve reason of installonly package for remove (Jaroslav Mracek)
- [3fd62ba7] Add logic for installonly packages and reason inheritance (Jaroslav Mracek)
- [4c8802ae] Adjust tsi reason according obsoleted packages (Jaroslav Mracek)
- [d9c28e4c] Create TSI for obsoleted packages (Jaroslav Mracek)
- [5f91614c] Store replaced package as optional and change name of variable (Jaroslav Mracek)
- [7171243d] Remove note that is not valid (Jaroslav Mracek)
- [dbe4ad86] Add get_reason() into TransactionItemPackage (Jaroslav Mracek)
- [6556e8fa] Add creation of transaction items in Transaction (Jaroslav Mracek)
- [68efbba0] Allow to store obsoleted an replaced packages in TransactionPackageItem (Jaroslav Mracek)
- [a7243b0d] Add operator< to Package and PackageId (Jaroslav Mracek)
- [125cf122] Change type of return value in GoalPrivate (Jaroslav Mracek)
- [510ebf59] Add 2 methods to GoalPrivate (Jaroslav Mracek)
- [1de14248] Move list_rpm from Goal to Transaction (Jaroslav Mracek)
- [b7f69f4a] Start to use a new transaction class by Goal (Jaroslav Mracek)
- [974e5718] Change code according to clang-format (Jaroslav Mracek)
- [3abfe585] Add new transaction class (Jaroslav Mracek)
- [f32ef046] Make read_login_uid_from_proc() more generic (Marek Blaha)
- [c1de314e] Move read_login_uid_from_proc() from microdnf to libnf (Marek Blaha)
- [fc87bd06] Add WeakPtr into Goal (Jaroslav Mracek)
- [01719db0] Define internal classes/structs in trans units into anonymous namespace (Jaroslav Rohel)
- [5ef93ec8] Make contructors without "base" argument private (Jaroslav Rohel)
- [52974652] Fix: advisory::AdvisoryQuery constructors with "base" argument (Jaroslav Rohel)
- [46100e4d] clang-format: BreakConstructorInitializers: BeforeColon (Lukáš Hrázký)
- [988b49a6] doc: Add libdnf_repo to the main index (Daniel Mach)
- [552a4ad1] test: Test for downgrade of package dbus API (Marek Blaha)
- [3e175f57] test: Test for upgrade of package dbus API (Marek Blaha)
- [310f4d90] test: Test for package removal dbus API (Marek Blaha)
- [2d7e7eea] test: Test for package install dbus API (Marek Blaha)
- [0ec3f96e] test: Adjust dbus repoconf test to common test data (Marek Blaha)
- [ef9d9a98] test: Create parent class for installroot tests (Marek Blaha)
- [dfc7441e] RepoQuery: get_base() (Daniel Mach)
- [95e037c9] Remove RepoQuery(const RepoSackWeakPtr &) ctor (Daniel Mach)
- [d7d9e83a] RepoQuery: Simplify public header (Daniel Mach)
- [79d6a5bc] RepoQuery: Add missing includes (Daniel Mach)
- [95fa5ebb] RepoQuery: Re-arrange forward decls (Daniel Mach)
- [00b847a8] doc: Improve repo::RepoQuery docstrings (Daniel Mach)
- [b28a8404] doc: Document QueryCmp (Daniel Mach)
- [b9104e54] doc: Remove old cpp_*.rst API documentation (Daniel Mach)
- [1178c8c9] Make transaction table closer to dnf's one (Daniel Mach)
- [a8e5fe2b] rpm: Add template functions for comparing nevra and naevr (Daniel Mach)
- [1fc96ddd] Nevra: Add == and << operators to make it usable in unit tests (Daniel Mach)
- [7355a7bb] Nevra: merge inline methods into the class definition (Daniel Mach)
- [d61aba24] solv::IdQueue: Move implementation of sort method to header file (Jaroslav Rohel)
- [5c68f082] solv::IdQueue: Better C++ interface for sort method (Jaroslav Rohel)
- [eb14423b] libdnf/solv: Clean up docstrings, small restructurization (Lukáš Hrázký)
- [0829bca3] libdnf/solv/solv_map: Use explicit casts instead of turning of conversion warnings (Lukáš Hrázký)
- [b7d07c9e] libdnf/solv/solv_map: Add the allocated_size() method, remove PackageSack friend (Lukáš Hrázký)
- [4b087910] libdnf/solv/id_queue: Remove the data() getter (Lukáš Hrázký)
- [8e6557bc] libdnf/solv/id_queue: Implement a C++ interface sort method (Lukáš Hrázký)
- [dd551900] Add a performance test for PackageQuery::filter_latest() (Lukáš Hrázký)
- [c7477200] libdnf/solv: Move iterators into the respective class headers (Lukáš Hrázký)
- [ab7cdbb1] libdnf/solv: Move short method inlines into class declaration, code formatting (Lukáš Hrázký)
- [60f794b6] Move libdnf/rpm/solv to libdnf/solv (Lukáš Hrázký)
- [a3a8346a] libdnf/transaction: Remove unneeded libsolv includes (Lukáš Hrázký)
- [8d0b3834] Add download step into reinstall command (Jaroslav Mracek)
- [fff0f1b2] Make errors more visible from microdnf (Jaroslav Mracek)
- [f460bd9f] Add get_base() method to Goal, Repo, and "*Sack" (Jaroslav Rohel)
- [8a0bc182] API stub for reasons (Daniel Mach)
- [e4bd1843] "*Query": Add constructors with "BaseWeakPtr" and "Base" argument (Jaroslav Rohel)
- [b2a1f262] `*SackWeakPtr`: Use `sack_quard` instead `data_quard` (Jaroslav Rohel)
- [359621d3] sack::Sack: Remove "QueryT" Template Argument (Jaroslav Rohel)
- [772dcc67] Remove "new_query" method from common sack::Sack (Jaroslav Rohel)
- [873d975c] Create "*Query" using ctor, remove "new_query" method from "*Sack" (Jaroslav Rohel)
- [73efc9b8] Fix a typo: downgarde->downgrade (Marek Blaha)
- [ea5ec979] Add downgrade() method to rpm::Transaction class (Marek Blaha)
- [e92c01a5] rpm::Transaction: Add get_base() method (Jaroslav Rohel)
- [566f69a1] rpm::Transaction: Store BaseWeakPtr instead Base*, add ctor with BaseWeakPtr (Jaroslav Rohel)
- [9e5b6762] Implement get_weak_ptr() for Base (Jaroslav Rohel)
- [c2199ef8] Remove TODO that is already implemented (Jaroslav Mracek)
- [289aa19f] Keep only the latest installed packages in install set (Jaroslav Mracek)
- [2164fb2f] Improve code for handling obsoletes in goal up_down_dist (Jaroslav Mracek)
- [2cc446ec] Remove commented but already implemented code and not valid comment (Jaroslav Mracek)
- [4bb9e89b] Throw LogicError when incorrect configuration value (Jaroslav Mracek)
- [05942a81] Report already installed packages when packageset is used (Jaroslav Mracek)
- [5e90e27f] [minor] Remove unneeded TODOs (Jaroslav Mracek)
- [7c3d77de] Disable unused-argument checking for TransactionCB for better readability (Daniel Mach)
- [bfd2d76f] goal: Fix to_repo_ids filtering (Marek Blaha)
- [7ab18648] Swig: Move repository implementation from rpm to new repo module (Jaroslav Rohel)
- [fbae37d2] Fix paths in "include" for moved repo implementation files (Jaroslav Rohel)
- [eaabfbe4] Move repository files from rpm to repo directories (Jaroslav Rohel)
- [aab99d06] Move repository code into new libdnf::repo namespace (Jaroslav Rohel)
- [616eb821] dnfdaemon: Optimize package_to_map() function (Marek Blaha)
- [a1e8cebf] dnfdaemon: move resolve() and do_transaction() to Goal interface (Marek Blaha)
- [4b48ad8b] dnfdaemon: package_to_map() to separate file (Marek Blaha)
- [62f72cef] Mark all upgrade operation as targeted (Jaroslav Mracek)
- [33c3a8ce] dnfdaemon: Fix the resolve() method (Marek Blaha)
- [c141e0e3] Address the situation when releasever is not set (Marek Blaha)
- [f559797c] Postfix notation in Query filters (Jaroslav Rohel)
- [9d2f4eaf] Postfix notation in TransactionQuery filters and default QueryCmp = EQ (Jaroslav Rohel)
- [69f1d735] Postfix notation in RepoQuery filters and default value QueryCmp = EQ (Jaroslav Rohel)
- [1b5af518] Postfix notation in GroupQuery filters and default value QueryCmp = EQ (Jaroslav Rohel)
- [09d6ebb4] Rename query methods "ifilter*" to "filter*" (Jaroslav Rohel)
- [91c69c0e] Add report for already installed packages (Jaroslav Mracek)
- [701c2fa9] Sort vector before the first element is taken (Jaroslav Mracek)
- [9c473976] Add logic for multilib_policy all in Goal install (Jaroslav Mracek)
- [111775e4] Remove commented code (Jaroslav Mracek)
- [ed0195ea] Rename Solv{Query,Sack} to Package{Query,Sack} (Daniel Mach)
- [0cd66645] Don't return a raw pointer from Package::get_repo() (Daniel Mach)
- [e522634c] Remove Package::get_size() (Daniel Mach)
- [79a07b8e] doc: Update guide on writing docstrings (Daniel Mach)
- [412a7130] doc: Improve rpm::Package docstrings (Daniel Mach)
- [2ee954be] Store cached solvable size (Jaroslav Mracek)
- [483fb317] Improve microdnf reinstall command (Jaroslav Mracek)
- [b9c68a25] Add rpm reinstall method to Goal (Jaroslav Mracek)
- [98afeaac] Tests of WeakPtr returned from "Base" object (C++, Python, Perl, Ruby) (Jaroslav Rohel)
- [d12c89fc] Added build dependency on perl(Test::Exception) (Jaroslav Rohel)
- [5ab3cf33] Use WeakPtr on more places, in API (Jaroslav Rohel)
- [d820edfe] Add libdnf::InvalidPointer exception (Jaroslav Rohel)
- [a24a3d4c] WeakPtr: Enable creation of WeakPtr that points to nullptr (Jaroslav Rohel)
- [66471126] dnfdaemon: remove unused DNFDAEMON_ERROR_REPLY macro (Marek Blaha)
- [e1080a2b] dnfdaemon: Use run_in_thread in base service methods (Marek Blaha)
- [69787893] dnfdaemon: Use run_in_thread in rpm service methods (Marek Blaha)
- [783834d7] dnfdaemon: Use run_in_thread in repoconf service methods (Marek Blaha)
- [82f1554e] dnfdaemon: Use run_in_thread in repo service methods (Marek Blaha)
- [f2156bff] dnfdaemon: session.run_in_thread() helper method (Marek Blaha)
- [d16e8c16] spec: Replace %{with tests_disabled} with %{with tests} (Daniel Mach)
- [c303a52e] Fix problem in SolvQuery::ifilter_name_arch() (Jaroslav Mracek)
- [ed6df924] Add SolvQuery filter for nevra with packageset (Jaroslav Mracek)
- [44536657] Add additional unit tests for NEVRA parsing (Jaroslav Mracek)
- [2b2903fc] Enhance implementation of Nevra iglob filter (Jaroslav Mracek)
- [ef65eae2] Do not search NEVRA patern with not NEVRA string (Jaroslav Mracek)
- [a83c4b44] Fix problem with NEV parsing (Jaroslav Mracek)
- [bbf45f38] Add exception for nevra parsing (Jaroslav Mracek)
- [2fd19c74] Do not create id for unknown reldep name for queries (Jaroslav Mracek)
- [37563799] dnfdaemon-cli: move code to repolist wrappers (Nicola Sella)
- [b3f75de4] Move XDG get_user_*_dir() functions from microdnf to libdnf utils (Jaroslav Rohel)
- [da3f7ae2] [microdnf] utils: better conformance with XDG in xdg::get_user_*_dir() (Jaroslav Rohel)
- [142c53ea] Add unit tests for split, rsplit, join (Jaroslav Rohel)
- [86f3ef1e] utils: Implement split and rsplit functions (Jaroslav Rohel)
- [5fa532aa] ArgumentParser: Unit tests (Jaroslav Rohel)
- [1b8ecea0] ArgumentParser: Add invalid argument id check (Jaroslav Rohel)
- [cb94e103] ArgumentParser: Add methods to get command/argument by ID path (Jaroslav Rohel)
- [77e78c41] ArgumentParser: Methods to get list of all stored arguments (Jaroslav Rohel)
- [60ab862f] [microdnf] Enable inheritance of named arguments in argument parser (Jaroslav Rohel)
- [a0cd6c28] ArgumentParser: Support inheritance of named arguments for parsing (Jaroslav Rohel)
- [5cd336d1] Perform test for empty name before creation of tmp values (Jaroslav Mracek)
- [bf2137aa] Add test for ':' in Name and NA (Jaroslav Mracek)
- [93a243eb] Add support of vector<Nevra> in bindings (Jaroslav Mracek)
- [7df41cc7] Remove old parsing method of Nevra (Jaroslav Mracek)
- [b6d406a9] Add new parsing method for nevra (Jaroslav Mracek)
- [aa375fd2] Replace multiple arguments by structure (Jaroslav Mracek)
- [0794be96] Convert SolvMap back from PackageId to Id, separate AdvisoryId (Aleš Matěj)
- [9287633c] Add unit test for Advisory, APackage AQuery and AModule (Aleš Matěj)
- [bbe5ccd4] Add advisories filter to solv query (Aleš Matěj)
- [1c82bef7] Start adding advisory command to microdnf (Aleš Matěj)
- [21a87fbe] Add AdvisoryReference (Aleš Matěj)
- [11c6826e] Add AdvisoryModule (Aleš Matěj)
- [ea5bb579] Add AdvisoryPackage (Aleš Matěj)
- [f7314e16] Add AdvisoryCollection (Aleš Matěj)
- [0a67d9c1] Add Advisory, AdvisorySack, and AdvisoryQuery (Aleš Matěj)
- [f478053f] Add unittest data for advisories tests (Aleš Matěj)
- [d4559ea0] dnfdaemon: Fix transaction table printing (Marek Blaha)
- [907ac3a0] dnfdaemon: Add downgrade command (Nicola Sella)
- [78389ea5] dnfdemon-cli: implement repoquery missing functions (Nicola Sella)
- [22af6a98] dnfdaemon: replace tuples with dictionaries in the resolve method (Nicola Sella)
- [79f08e53] Move code from hpp to cpp (Jaroslav Mracek)
- [b254d214] Initialized to use tito. (Jaroslav Mracek)
- [80583eaf] Add changes created by clang-format (Jaroslav Mracek)
- [e3ab7dad] Move content of utils.hpp into proper place (Jaroslav Mracek)
- [e6274037] Remove unneeded temporary query (Jaroslav Mracek)
- [9a782ade] comps: CLI commands grouplist and groupinfo (Pavla Kratochvilova)
- [c3981b8f] comps: Separate installed and available groups (Pavla Kratochvilova)
- [6bf60afd] comps: Add QroupQuery filter by group name (Pavla Kratochvilova)
- [8c4051a0] comps: Add fake method to get installed groups (Pavla Kratochvilova)
- [734b26b7] comps: Test dumping and loading group produces the same group (Pavla Kratochvilova)
- [d4052bbf] comps: Add method to dump group into xml (Pavla Kratochvilova)
- [2e763153] comps: Add method to get group packages by type (Pavla Kratochvilova)
- [ec3a2c97] comps: Add tests for loading and merging groups (Pavla Kratochvilova)
- [3549f5e8] comps: Add functionality to create new query (Pavla Kratochvilova)
- [ba8e8892] comps: Add loading comps from file (Pavla Kratochvilova)
- [77dc04a8] comps: Add group attributes and getting them from solvables (Pavla Kratochvilova)
- [189191ab] comps: Initial support for loading groups (Pavla Kratochvilova)
- [1eebb7fc] dnfdaemon-client: Unneeded unique_ptrs (Marek Blaha)
- [27460592] dnfdaemon-client: Run remove command allways with allow_erasing on (Marek Blaha)
- [ce62607e] dnfdaemon: Remove hardcoded default strict option value (Marek Blaha)
- [054b6e66] dnfdaemon-client: --strict option requires value (Marek Blaha)
- [166aa263] dnfdaemon: Make package matching configurable (Marek Blaha)
- [b30a9f77] Remove unused function: name_compare_lower_solvable() (Lukáš Hrázký)
- [07fa4353] Cast format_size() argument to int64_t (Lukáš Hrázký)
- [ea287f14] microdnf: use smartcols in downgrade (Nicola Sella)
- [8986aab4] dnfdaemon-client: move wrapper to separate files (Nicola Sella)
- [a29672d8] l/o/transaction_table.hpp: rename print_goal to print_transaction_table (Nicola Sella)
- [a9946a19] l/o/transaction_table.hpp: Sort output (Nicola Sella)
- [790fcdde] dnfdaemon-server: Add size to DbusTransactionItem (Nicola Sella)
- [64fcc2f3] dnfdaemon-client: Add DbusPackageWrapper, DbusGoalWrapper (Nicola Sella)
- [236c3230] microdnf: move print_goal code to transaction_table.hpp (Nicola Sella)
- [93511354] CI: Take the name of the repository from upstream (Lukáš Hrázký)
- [a5eaca8f] Fix check whether the subkey can be used for signing (Dmitry Antipov)
- [9d16e957] Add unit test for Goal::.add_rpm_downgrade() (Jaroslav Mracek)
- [af4db649] Add downgrade command to microdnf (Jaroslav Mracek)
- [f1d4de83] Implement rpm downgrade functionality in Goal (Jaroslav Mracek)
- [cbdff293] Add support of clean_requirement on remove for install job (Jaroslav Mracek)
- [b2eb9bf5] Improve reports for upgrade and distrosync (Jaroslav Mracek)
- [95f17579] Add new filters for SolvQuery (Jaroslav Mracek)
- [efbcffb1] Lock "installroot" in load_system_repo or transaction_db_connect (Jaroslav Rohel)
- [cee25818] Unit tests for "Option *" classes (Jaroslav Rohel)
- [26a50b0b] Fix: OptionSeconds: Set minimum value to -1 by default (Jaroslav Rohel)
- [7b292339] Add comment argument to Option::lock() method (Jaroslav Rohel)
- [862a09b7] Add support to lock "Option" (Jaroslav Rohel)
- [8dc92a8b] dnfdaemon: Use libsolv's Id as package identifier in signals (Marek Blaha)
- [bcf42824] dnfdaemon-client: Transaction progress bars (Marek Blaha)
- [dca7e208] dnfdaemon-client: Package download progress bars (Marek Blaha)
- [eaca8368] dnfdaemon-client: Move callbacks to separate files (Marek Blaha)
- [e40606ce] dnfdaemon: Emit dbus signal after whole rpm transaction is finished (Marek Blaha)
- [f188763d] dnfdaemon: Signals on rpm transaction progress. (Marek Blaha)
- [eed252e5] dnfdaemon: Refactor callbacks structure (Marek Blaha)
- [24d2c142] dnfdaemon: Add package download callbacks (Marek Blaha)
- [873baa7d] dnfdaemon: Move callbacks to separate file (Marek Blaha)
- [09a40e54] dnfdaemon: Clang format fixes (Marek Blaha)
- [14922825] Fix build on CentOS Stream 8 (Daniel Mach)
- [0ab78369] Do not move const GoalSettings (Jaroslav Mracek)
- [6aa6c4b4] Add Goal reset method (Jaroslav Mracek)
- [bc030a1f] Fix copy constructor and create = operator for GoalPrivate (Jaroslav Mracek)
- [68353f03] Remove cached goal jods after processing (Jaroslav Mracek)
- [6a2357c3] Use correct data from settings for remove (Jaroslav Mracek)
- [8839c8b9] Allow to store values used for job during resolve() (Jaroslav Mracek)
- [c2782f34] Exception: format() - return a string, what() with nested exceptions (Jaroslav Rohel)
- [88d28ce6] Exception::what() return full explanatory message, SystemError: remove "path" (Jaroslav Rohel)
- [2137b843] Fix: libdnf::SystemError::what(): add missing "] " (Jaroslav Rohel)
- [70dc9c8e] Add libdnf-cli dependency on libdnf (Jaroslav Rohel)
- [bc3a5f58] Use TestCaseFixture for some test cases (Jaroslav Rohel)
- [f6341fa5] New TestCaseFixture class: Restore "environ" after test case (Jaroslav Rohel)
- [855b0c7a] [microdnf] Support "--installroot" and "--releasever" cmd line arguments (Jaroslav Rohel)
- [04e6a79d] "installroot" support (Jaroslav Rohel)
- [d6d0c683] [microdnf] Support "--setvar" command line argument (Jaroslav Rohel)
- [4dca0fbc] Vars source/priority support (Jaroslav Rohel)
- [2701aae8] Improve detect_arch() and detect_release() (Jaroslav Rohel)
- [8a8103f2] Move include/utils to include/common or among private headers (Daniel Mach)
- [f02ef9c8] dnfdaemon-client: Do not hide command errors (Marek Blaha)
- [4e67d172] dnfdaemon-client: Remove command (Marek Blaha)
- [efb70086] dnfdaemon: Remove a package (Marek Blaha)
- [daf32fcd] [clang-format] Change format (Marek Blaha)
- [16ca7a1f] dnfdaemon-client: Upgrade command (Marek Blaha)
- [61d8b5ac] dnfdaemon-client: New base class for transaction commands (Marek Blaha)
- [ab120301] dnfdaemon-client: Make allowerasing a global option (Marek Blaha)
- [404cf991] dnfdaemon: Upgrade a package (Marek Blaha)
- [071ed204] Fix RpmHeader::get_release() method (Marek Blaha)
- [136b8dd8] Add Nevra class in bindings (Jaroslav Mracek)
- [97eff620] Remove a default case from the switch (Jaroslav Mracek)
- [b7cbbfc2] doc: Rearrange html docs to make them easier to read (Daniel Mach)
- [791a868b] doc: Configure for building in Read the Docs (Daniel Mach)
- [40eced7e] doc: Update copyright year in conf.py (Daniel Mach)
- [4538bf6e] doc: Migrate Doxyfile to version 1.9.1 (Daniel Mach)
- [d891c040] MultiProgressBar not to take over ownership of bars pointers (Marek Blaha)
- [8d509344] CI: Build with clang in a matrix with gcc build (Lukáš Hrázký)
- [c9ce8e20] Add a --with clang option to .spec (Lukáš Hrázký)
- [7bbd0d92] CMake: Adjust compiler options for compiling with clang (Lukáš Hrázký)
- [fcce64fe] include/libdnf/utils/utils.hpp: Return values directly from GoalJobSettings getters (Lukáš Hrázký)
- [1cfc2457] libdnf-cli/output/repolist.hpp: Change the type of sort_column (Lukáš Hrázký)
- [e8c5f9a8] libdnf-cli/output/repo_info.hpp: Cast the format_size argument to signed (Lukáš Hrázký)
- [271623f9] libdnf-cli/output/key_value_table: Add a templated add_line for numbers (Lukáš Hrázký)
- [f265d93f] dnfdaemon-client: Remove unused class members (Lukáš Hrázký)
- [86aae54a] dnfdaemon-client: Cast dbus timetout to uint64_t (Lukáš Hrázký)
- [02e1876f] libdnf/utils/sqlite3/sqlite3.hpp: Use int64 internally for uint32_t (Lukáš Hrázký)
- [76caf6a5] libdnf/transaction/rpm_package.cpp: Fix get_epoch_int signedness issues (Lukáš Hrázký)
- [6ff82b16] libdnf/rpm/solv_sack_impl.hpp: Remove a superfluous std::move (Lukáš Hrázký)
- [90f26a9d] libdnf/rpm/solv_sack.cpp: Remove MODULE_FAIL_SAFE_REPO_NAME (Lukáš Hrázký)
- [61cdb5e1] libdnf/rpm/solv/package_private.hpp: Use Id instead of unsigned (Lukáš Hrázký)
- [752e0e86] libdnf/rpm/repo.cpp: Fix signedness issues (Lukáš Hrázký)
- [1ba42a1e] libdnf/rpm/config_repo.cpp: Remove the owner member of ConfigRepo::Impl (Lukáš Hrázký)
- [a45e2c3f] libdnf/conf/vars.cpp: Fix implicit type conversion issues (Lukáš Hrázký)
- [f6f4a3df] libdnf/base/goal.cpp: drop unused cstring2string() (Lukáš Hrázký)
- [379f995e] libdnf-cli/utils/utf8.cpp: Fix implicit type conversion issues (Lukáš Hrázký)
- [36ffdf5a] rpm::Repo: Change verify_id() return type to std::string::size_type (Lukáš Hrázký)
- [e641b4c6] [clang-format] Change format by clang-format (Jaroslav Mracek)
- [837b532a] Make cmp_type optional in SolvQuery (Jaroslav Mracek)
- [f2896d7d] Apply proxy certificate options (Jaroslav Rohel)
- [288213c0] [conf] Add options for working with certificates used with proxy (Jaroslav Rohel)
- [f12826b3] Fix: Fully set ssl in newHandle function (Jaroslav Rohel)
- [1a223e81] Remove redundant libdnf:: namespace (Jaroslav Mracek)
- [531cc1cd] Allow to set ICASE from API for goal jobs (Jaroslav Mracek)
- [63680d76] Add unit tests for Goal upgrade and distrosync (Jaroslav Mracek)
- [aed8cd92] Add hints when nothing found for an argument (Jaroslav Mracek)
- [bd509e56] Fix install for glob argument with not just name (Jaroslav Mracek)
- [eb1db483] Report resolve log to terminal (Jaroslav Mracek)
- [53ccfcae] Add function to accumulate strings (Jaroslav Mracek)
- [ce10fc3d] Use reference of setting instead of a copy (Jaroslav Mracek)
- [b318e758] Rename GoalSettings to GoalJobSettings (Jaroslav Mracek)
- [48e6210a] Change a code according to changed API (Jaroslav Mracek)
- [c7ce31f9] Improve reports for Goal.rpm_upgrade() (Jaroslav Mracek)
- [8f38b4b6] Unify API arguments for Goal class (Jaroslav Mracek)
- [f9f2a34e] Add settings for search patterns for goal methods (Jaroslav Mracek)
- [e3ecb8ee] Unify reports in Goal class for not found event (Jaroslav Mracek)
- [beced98c] Add support for distrosync (Jaroslav Mracek)
- [28aade59] Add upgrade all for goal (Jaroslav Mracek)
- [1aa29c52] Do not set best, cleandeps_on_remove as global option (Jaroslav Mracek)
- [7210c7cc] [dnfdaemon] use libdnf::cli::output to print repoquery (Nicola Sella)
- [f537cf5a] Add SolvQuery::ifilter_priority() (Jaroslav Mracek)
- [0a0b704b] Add SolvQuery::ifilter_latest() and clang changes (Jaroslav Mracek)
- [a956cd09] [clang] Apply changes suggested by clang-format (Jaroslav Mracek)
- [08cdbbca] dnfdaemon-client: install command (Marek Blaha)
- [f0004af6] dnfdaemon: Repository loading progress bars (Marek Blaha)
- [7b0b6e71] dnfdaemon: Document SessionManager and Rpm interfaces (Marek Blaha)
- [1ec53746] dnfdaemon: Install a package (Marek Blaha)
- [df57486f] dnfdaemon: Configuration option to override session releasever (Marek Blaha)
- [9d139b9e] [cli] Add reset method to progress bar class (Marek Blaha)
- [23da154a] [cli] Current speed ticks not to go down (Marek Blaha)
- [f275f961] conf: Add Vars::set_value(string, string) method (Marek Blaha)
- [d90c7e21] dnfdaemon: Session remembers addres of client who opened it (Marek Blaha)
- [91cefa18] dnfdaemon: Add a Goal instance to the session (Marek Blaha)
- [dd210de8] dnfdaemon: Move authorization check to session (Marek Blaha)
- [f12ee6b3] [clang] Add supposed changes by clang (Jaroslav Mracek)
- [99d07e1e] Add setter for Repo cost and priority (Jaroslav Mracek)
- [d3a36901] daemon-client: Implement repoinfo command using smartcols (Daniel Mach)
- [a3d1a2b1] cli: Move format_size() under utils (Daniel Mach)
- [31937be2] Add QueryRepoDbus to dnfdaemon (Nicola Sella)
- [f91a513e] Add get_name alias to Repo object (Nicola Sella)
- [51c41d5a] Use libdf::cli::output code for repolist (Nicola Sella)
- [abf667cc] Protect kernel according to configuration (Jaroslav Mracek)
- [135490ab] Backport 3 configuration option from dnf-4 (Jaroslav Mracek)
- [784da9ac] Use static_cast and minor style changes (Jaroslav Mracek)
- [c7c025d2] Rename a variable by a proper name (Jaroslav Mracek)
- [30207379] Change code according to clang (Jaroslav Mracek)
- [68473648] Set allow erasing true for remove operation in microdnf (Jaroslav Mracek)
- [299db754] Report removal of protected packages and running kernel (Jaroslav Mracek)
- [c2dff73c] Specify an error type in return value of Goal::resolve() (Jaroslav Mracek)
- [d027b03d] Move enum to a new place and add operators (Jaroslav Mracek)
- [61a7375a] Add test for removal of protected packages in transaction (Jaroslav Mracek)
- [536dca93] Add running kernel detection (Jaroslav Mracek)
- [34114ebc] Allow to remove installonly packages over installonly limit (Jaroslav Mracek)
- [94ab2ba5] Move a function to place from where can be imported (Jaroslav Mracek)
- [272e5c10] Add two methods for Solvmap (Jaroslav Mracek)
- [fd4c5692] Add basic support for installonly packages in rpm::Goal (Jaroslav Mracek)
- [e65a5501] Tests for bindings use tmpdir for cache and solv files (Aleš Matěj)
- [a45ea9ea] tests: Rename to_vector() to to_vector_string() (Daniel Mach)
- [c0e566dd] Avoid creating %{ARCH} subdir when building test rpms (Daniel Mach)
- [5305e3f4] Fix test_goal after migrating to generated test data (Daniel Mach)
- [7a65dca7] libdnf: Ensure library is correctly linked with libdl (Neal Gompa)
- [968ccb38] Fix: Goal - translation of messages in global map (Jaroslav Rohel)
- [46b50740] CMakeList.txt: Enable C language and scan for *.c files in libdnf (Jaroslav Rohel)
- [7e24c4ff] [dnfdaemon] Unify repo list API with rpm list (Marek Blaha)
- [42fc320d] CI: Rename ci.yaml -> ci.yml to unify extensions (Lukáš Hrázký)
- [06873459] CI: Use the pre-generated CI host image (Lukáš Hrázký)
- [c2bcd499] Deduplicate code - create string_to_proxy_auth_methods() function (Jaroslav Rohel)
- [3cef921e] Change return value of Goal::resolve to enum (Jaroslav Mracek)
- [0068cec3] Remove unneeded line (Jaroslav Mracek)
- [54a9ad50] Add changes suggested by clang (Jaroslav Mracek)
- [40d4a6ca] Add solver problem reports for microdnf (Jaroslav Mracek)
- [588dd521] Add method to get formatted problems from goal (Jaroslav Mracek)
- [473b7809] Add Goal::describe_all_solver_problems() (Jaroslav Mracek)
- [54a83857] Add method to report solver errors (Jaroslav Mracek)
- [5123df8d] Set goal flags according to configuration (Jaroslav Mracek)
- [c4da58cc] Set protected packages in GoalPrivate (Jaroslav Mracek)
- [3790797a] Replace generic exceptions by specific from libdnf (Jaroslav Mracek)
- [46fe27a8] Add  GoalPrivate::count_solver_problems() (Jaroslav Mracek)
- [6dc57594] Add createrepo_c build require for tests (Lukáš Hrázký)
- [aa4ad80d] CI: Build for all relevant Fedora chroots (Lukáš Hrázký)
- [d898c350] tests: Replace binary with plain text test data (Daniel Mach)
- [57503213] Change Exception and SystemException what() output (Daniel Mach)
- [21329c3a] Add unit test for goal.install_or_reinstall() (Jaroslav Mracek)
- [eed4ba95] Add checks to prevent using of different instances of Sack (Jaroslav Mracek)
- [a9101036] Add goal.install_or_reinstall() (Jaroslav Mracek)
- [daf289e3] Fix problematic language (Lukáš Hrázký)
- [0e7d4fea] Rename ConfigRepo member master_config to main_config (Lukáš Hrázký)
- [c87833f9] dnf-4: Fix problematic language (Lukáš Hrázký)
- [0552741a] Add CI building rpms in Copr (Lukáš Hrázký)
- [bb6a8af9] [dnfdaemon] Repoconf service uses session configuration (Marek Blaha)
- [5c137f7e] [plugins] Modify CMakeLists.txt and .spec files (Jaroslav Rohel)
- [2995f642] [microdnf] Load plugins (Jaroslav Rohel)
- [33ddb4bd] [plugins] Python test plugin for libdnf (Jaroslav Rohel)
- [9168c198] [plugins] Plugin for loading Python plugins (Jaroslav Rohel)
- [7b1c302d] [plugins] Prepare building of libdnf plugins (Jaroslav Rohel)
- [8742bd2e] [plugin] Add methods for working with plugins in Base (Jaroslav Rohel)
- [1de148c1] [plugin] Add SWIG bindings (Jaroslav Rohel)
- [6bfee3c6] [plugin] Plugin access classes and Plugin manager (Jaroslav Rohel)
- [d8ba394f] [plugin] API for C++ plugins (Jaroslav Rohel)
- [493ce564] [utils] "Library" class - For working with shared libraries (Jaroslav Rohel)
- [8ca792f7] [Base] Methods lock(), unlock(), get_locked_base() (Jaroslav Rohel)
- [700568d4] Fix notnull compilation errors on gcc 11 (Daniel Mach)
- [09ff30e0] tests: Always run utf8 tests with C.UTF-8 locales (Daniel Mach)
- [633d6a58] [microdnf] Fix error if there is no argument "--comment" (Jaroslav Rohel)
- [0e0b22f1] [dnfdaemon] Tests for rpm list API (Marek Blaha)
- [1ef78e9a] [dnfdaemon] Rename patterns_to_show attribute to patterns (Marek Blaha)
- [432114e5] [dnfdaemon-client] New hook to configure session from cmdline args (Marek Blaha)
- [47878ade] [dnfdaemon] Add fill_sack session method (Marek Blaha)
- [dc2c1a90] [dnfdaemon] Only one dbus_object on session level (Marek Blaha)
- [be9fe30e] [dnfdaemon-client] Repoquery command (Marek Blaha)
- [b8dcacb1] [dnfdaemon] Repoquery command - server side (Marek Blaha)
- [fc9c461e] [dnfdaemon] Store repositories status in Session object (Marek Blaha)
- [09060e4b] [dnfdaemon] Move RepoStatus enum to server (Marek Blaha)
- [b0720275] [dnfdaemon] Move read_all_repos to Session (Marek Blaha)
- [33c513e0] [dnfdaemon] Basic tests for repolist API (Marek Blaha)
- [15a4c2ed] [dnfdaemon] Repositories are returned sorted by their id (Marek Blaha)
- [bcfdd7a4] [dnfdaemon] Allow runtime override of installroot connected configs (Marek Blaha)
- [88815940] [dnfdaemon] Move session_configuration_value template implementation to .hpp (Marek Blaha)
- [a4bf0369] spec: Fix running the tests after build (Daniel Mach)
- [0cccf226] swig: Use the full module names for each language (Daniel Mach)
- [d5c9e53a] tests: Use relative import to common.Iterator (Daniel Mach)
- [4c01a0f3] Temporarily disable Go bindings in spec (Lukáš Hrázký)
- [ea5562fb] cmake: Fix python3 (Daniel Mach)
- [103380f3] cmake: Use pkgconfig to find sdbus-cpp (Daniel Mach)
- [eae437e4] Fix notnull compilation errors on gcc 11 (Daniel Mach)
- [57752649] spec: Fix Fedora 34 build (Daniel Mach)
- [c3baf0ce] Use relative imports in python3 bindings (Daniel Mach)
- [8636dcb3] Rename dnfdaemon.service to avoid file conflict with dnfdaemon package (Daniel Mach)
- [95f18680] Update CMakeLists with latest compile options from Fedora 34 (Daniel Mach)
- [ae1bf370] Replace chdir() with current_path() to mute a unused return value warning (Daniel Mach)
- [c42f2cff] Remove unused code to mute a compiler warning (Daniel Mach)
- [2a33dff9] Rename Item to QueryItem to mute ODR compiler warnings (Daniel Mach)
- [3b8ae1f0] Check mkdtemp return value (Daniel Mach)
- [e6aba2ab] output: Always print Epoch in the info output (Daniel Mach)
- [cf97c38f] rpm: Make the Package object compatible with to(_full)_nevra_string() template functions (Daniel Mach)
- [f3668e00] [conf] Add armv6hl to the architecture table (Neal Gompa)
- [f2c3cf4f] rpm::PackageSet::Impl: rpm::solv::SolvMap assignment (Jaroslav Rohel)
- [70c19fd6] Goal: remove redundant methods that accept rpm::SolvQuery (Jaroslav Rohel)
- [a02e1661] Unification: Rename - "p_impl" in all places (Jaroslav Rohel)
- [6cdfe882] rpm::SolvQuery: store init_flags (Jaroslav Rohel)
- [a9c641f1] Move sacks equality tests from SolvQuery to PackageSet (Jaroslav Rohel)
- [0ed6f36b] rpm::SolvQuery: remove get_package_set() - SolvQuery can be used directly (Jaroslav Rohel)
- [355238de] Use rpm::SolvQuery directly instead of rpm::PackageSet (Jaroslav Rohel)
- [d0580f7b] tests: iterate directly through SolvQuery instead of PackageSet (Jaroslav Rohel)
- [6070cdb5] rpm::SolvQuery inherits rpm::PackageSet (Jaroslav Rohel)
- [0e80310d] rpm::SolvQuery: contains PackageSet instead of SolvSackWeakPtr and SolvMap (Jaroslav Rohel)
- [84f108cc] rpm::PackageSet: Add copy and move assignment operators, improve move ctor (Jaroslav Rohel)
- [9a8f79f7] rpm::solv::PackageSet: add swap() method, add noexcept to methods (Jaroslav Rohel)
- [6dafd716] rpm::solv::SolvMap: Improve copy and move assignment operators (Jaroslav Rohel)
- [b03d8dde] rpm::solv::SolvMap: add swap() method, add noexcept to methods (Jaroslav Rohel)
- [1951e318] [tests][Python] rpm.ReldepList (Jaroslav Rohel)
- [18769f73] tests: libdnf::WeakPtr: test self-assignment (Jaroslav Rohel)
- [eb58b9ec] libdnf::WeakPtr: assignment operators: Add check for self-assignment (Jaroslav Rohel)
- [8a9b064a] [microdnf] Commands "install", "remove", "upgrade" write to database (Jaroslav Rohel)
- [5ad61842] [microdnf] Implement get_login_uid() (Jaroslav Rohel)
- [42b31932] [microdnf] Add "--comment" argument (Jaroslav Rohel)
- [cfae41ca] [microdnf] Store reference to program arguments to context (Jaroslav Rohel)
- [cf649e37] tests: Iteration of PackageSet in Python (Jaroslav Rohel)
- [369af76d] [dnf5, swig] Fix: Python iterator wrapper - save container reference (Jaroslav Rohel)
- [835f68b6] Add SolvSack::get_nsolvables() - returns number of solvables in pool (Jaroslav Rohel)
- [bf9fc272] Improve performance of ifilter_installed() (Jaroslav Rohel)
- [1459275f] Improve performance of ifilter_installed() and ifilter_available() (Jaroslav Rohel)
- [2eb6147b] tests: better tests for rpm::solv::IdQueueIterator (Jaroslav Rohel)
- [865b7fd1] Rewrite rpm::solv::IdQueueIterator (Jaroslav Rohel)
- [ba7db757] Optimize rpm::PackageSet, rpm::ReldepList iterators - remove current_value (Jaroslav Rohel)
- [190168cd] tests: better tests for rpm::PackagSetIterator, rpm::ReldepListIterator (Jaroslav Rohel)
- [0ecea104] Fix operator++(int) in rpm::PackageSetIterator,  rpm::ReldepListIterator (Jaroslav Rohel)
- [26beac1c] Ddifference_type, reference in rpm::PackageSetIterator, rpm::ReldepListIterator (Jaroslav Rohel)
- [ad598616] tests: rpm::solv::SolvMapIterator::jump() (Jaroslav Rohel)
- [6ee36c53] Implement rpm::solv::SolvMapIterator::jump() (Jaroslav Rohel)
- [c403fe8d] tests: begin() and end() rpm::solv::SolvMap iterator tests (Jaroslav Rohel)
- [bf0cfa00] Fix begin() and end() in rpm::solv::SolvMapIterator (Jaroslav Rohel)
- [821625de] Mark rpm::solv::SolvMapIterator methods "noexcept", difference_type, reference (Jaroslav Rohel)
- [8b888d31] tests: more rpm::solv::SolvMap iterator tests (Jaroslav Rohel)
- [36fa91ca] Fix rpm::solv::SolvMapIterator::operator++(int) (Jaroslav Rohel)
- [768cc3c9] Enable usage of zchunk metadata format in libdnf (Marek Blaha)
- [83f19602] Implement allow_vendor_change option in solver (Neal Gompa)
- [153d2819] transaction: Change 'begin' to 'start' in the Transaction class (Daniel Mach)
- [872910a2] transaction: Add docstrings (Daniel Mach)
- [865c7b4f] transaction: Apply clang-format (Daniel Mach)
- [8e23d912] transaction: Make header files public (Daniel Mach)
- [3d6e6035] transaction: Implement TransactionSack (Daniel Mach)
- [3a03befc] transaction: Refactor TransactionItem inheritance, keep each type in its own vector. (Daniel Mach)
- [a60efbf5] transaction: Remove PackagePtr (Daniel Mach)
- [3c3a3d95] transaction: Move CompsEnvironment low-level db code to separate files (Daniel Mach)
- [118b6974] transaction: Move CompsEnvironmentGroup low-level db code to separate files (Daniel Mach)
- [292ebb9f] transaction: Move CompsGroup low-level db code to separate files (Daniel Mach)
- [e8935cdf] transaction: Move CompsGroupPackage low-level db code to separate files (Daniel Mach)
- [78791179] transaction: Move Transaction.console_output low-level db code to separate files (Daniel Mach)
- [1ae0b445] transaction: Remove unused nevraToPackage() from tests (Daniel Mach)
- [d77606fa] transaction: Remove Package.getNEVRA() (Daniel Mach)
- [3932e4ed] transaction: Rewrite Transaction.softwarePerformedWith to runtime_packages (Daniel Mach)
- [94672b69] transaction: Change Package.epoch type from int to string (Daniel Mach)
- [aca3caff] transaction: Move more Package low-level db code to separate files (Daniel Mach)
- [22c98850] transaction: Drop Repo class, handle repoid in TransactionItem (Daniel Mach)
- [4847541e] transaction: Rewrite RPMItem (Daniel Mach)
- [a2d088b1] transaction: Rewrite CompsEnvironmentItem (Daniel Mach)
- [2bae5b2b] transaction: Rewrite CompsGroupItem (Daniel Mach)
- [470fa760] transaction: Remove SQLite3 from constructors, reduce shared_ptr usage (Daniel Mach)
- [26f3ff3f] transaction: Remove get*Item() methods from TransactionItem (Daniel Mach)
- [a905ee44] transaction: Remove unused operators from TransactionItem (Daniel Mach)
- [c7fc6356] transaction: Move Transaction low-level db code to separate files (Daniel Mach)
- [e234452f] transaction: Move Item low-level db code to separate files (Daniel Mach)
- [358e0d33] transaction: Move RPMItem low-level db code to separate files (Daniel Mach)
- [a95cee7d] transaction: Split 'Types.hpp' into individual headers (Daniel Mach)
- [6d3cc089] transaction: Rewrite TransactionItem (Daniel Mach)
- [e6173cc9] transaction: Merge TransactionItemBase into TransactionItem (Daniel Mach)
- [80e8f360] transaction: Rewrite Transaction class (Daniel Mach)
- [a037f419] transaction: Move classes to libdnf::transaction namespace (Daniel Mach)
- [ac6a0125] transaction: Move TransformerTransaction from private namespace (Daniel Mach)
- [cce50982] transaction: Move Repo from private namespace (Daniel Mach)
- [8aa8ed84] transaction: Merge private Transaction into the public class (Daniel Mach)
- [6fbd0c31] transaction: Rewrite TransactionItemAction (Daniel Mach)
- [6e16ce36] transaction: Rewrite TransactionItemReason (Daniel Mach)
- [8236faf0] transaction: Fix compilation issues in tests (Daniel Mach)
- [de72f874] transaction: Move tests to the new location (Daniel Mach)
- [f25ebcc7] transaction: Fix compilation issues (Daniel Mach)
- [c3dca805] transaction: Move files to the new location (Daniel Mach)
- [05d23507] weak_ptr: Implement operator*() (Daniel Mach)
- [b9adc0a0] sack: Implement protected get_data_guard() method (Daniel Mach)
- [9e89aca2] sqlite3: Make get_db() part of Statement public API (Daniel Mach)
- [e4d66d21] sqlite3: Make last_insert_rowid() part of Statement public API (Daniel Mach)
- [7f7bf4a2] Improve performance of ifilter_installed() (Jaroslav Mracek)
- [c30bf39c] Resolve installed faster when no installed repository (Jaroslav Mracek)
- [341d3044] [dnfdaemon] Minor fixes (Marek Blaha)
- [b21de2a2] [dnfdaemon] Set correct required version of sdbus-cpp (Marek Blaha)
- [04daa92e] [dnfdaemon] Replace ifilter_reponame -> ifilter_repoid (Marek Blaha)
- [f46b877f] [dnfdaemon-client] Use ArgumentParser from libdnf::cli (Marek Blaha)
- [cea41067] [dnfdaemon] Threads manager (Marek Blaha)
- [35032381] [dnfdaemon] Fix several deadlocks (Marek Blaha)
- [6863034c] [dnfdaemon] Correctly join all created threads (Marek Blaha)
- [e25d09a2] [dnfdaemon] Catch repository loading errors (Marek Blaha)
- [4abae03e] [dnfdaemon-client] Repoinfo command (Marek Blaha)
- [0e084932] [dnfdaemon] Repoinfo - server part (Marek Blaha)
- [aa61533c] [dnfdaemon-client] Basic infrastructure + repolist (Marek Blaha)
- [7b93ca6d] [dnfdaemon] Repolist - server part (Marek Blaha)
- [250e54fc] Switch sanitizers from LD_PRELOAD to ASAN_OPTIONS (Lukáš Hrázký)
- [32633fb1] [cli] Add "Repository" line into package info table (Jaroslav Rohel)
- [be316d73] tests: Add unittests for libdnf::Span (Jaroslav Rohel)
- [43ae9c93] libdnf::Span: simplified implementation of C++20 std::span container (Jaroslav Rohel)
- [f631251d] rpm: Add template functions for creating nevra string and copying nevra attributes (Daniel Mach)
- [216a329c] [argparser] Support PositionalArg without setting storage field "values" (Jaroslav Rohel)
- [f36f3a39] [argparser] Fix: PositionalArg constructor: Check "values" before use (Jaroslav Rohel)
- [078f11aa] [microdnf] Add "--assumeyes", "-y" and "--assumeno" arguments (Jaroslav Rohel)
- [d950f3e4] [microdnf] Respect "assumeyes"  and "assumeno" from config (Jaroslav Rohel)
- [0fd7d455] Add operators to SolvQuery (Jaroslav Mracek)
- [9aa5d851] microdnf: Add a TODO to single-threaded repo loading implementation (Lukáš Hrázký)
- [85f1f55a] Fix ReldepList::add_reldep_with_glob() (Lukáš Hrázký)
- [dc0713d9] repo: Return reference instead of pointer from get_config() (Lukáš Hrázký)
- [fbdbe68b] tests/libdnf/rpm/test_reldep_list: Use RepoFixture (Lukáš Hrázký)
- [5328154f] Don't wrap Repo::Impl::conf in unique_ptr and rename to "config" (Lukáš Hrázký)
- [ae8eaefe] Add const getters to Config classes (Lukáš Hrázký)
- [6f5588bc] Remove ConfigRepo from Repo constructor (Lukáš Hrázký)
- [37610eec] Add basic tests for the conf module (Lukáš Hrázký)
- [e678d4c3] Add tests for the Vars class (Lukáš Hrázký)
- [845c790e] test/libdnf/utils: Move to_vector(...) definition to a .cpp file (Lukáš Hrázký)
- [2d7bd898] Introduce the Vars class and consolidate the substitutions functionality (Lukáš Hrázký)
- [9403c5cb] [microdnf] Code deduplication: Use "microdnf::userconfirm()" (Jaroslav Rohel)
- [35c37ad8] [microdnf] Use prepare_transaction() (Jaroslav Rohel)
- [94250d94] [microdnf] Implement prepare_transaction() (Jaroslav Rohel)
- [e4171497] [microdnf] Implement print_goal() - print action table (Jaroslav Rohel)
- [2de3b41d] [microdnf] Add download_packages() that accepts libdnf::Goal (Jaroslav Rohel)
- [eefdd802] [microdnf] download_packages() accepts std:vector<libdnf::rpm::package> (Jaroslav Rohel)
- [107a32b3] libdnf: Bump shared object version (Neal Gompa)
- [6a78ef78] Change code according to clang recommendations (Jaroslav Mracek)
- [fa8afbf6] Add unittests for add_cmdline_rpm and add_system_rpm (Jaroslav Mracek)
- [6502eb2c] Add SolvSack.add_system_package() (Jaroslav Mracek)
- [748c6ef5] Add SolvSack.add_cmdline_package() (Jaroslav Mracek)
- [a919afe9] Add test with icase for libdnf::rpm::SolvQuery.resolve_pkg_spec() (Jaroslav Mracek)
- [ce726413] Add 4 filters for SolvQuery (Jaroslav Mracek)
- [2417c4d8] Improve performance for SolvQuery name icase search (Jaroslav Mracek)
- [c474f846] [argparser] Move multiline methods from .hpp to .cpp (Jaroslav Rohel)
- [ecb0386f] [argparser] Command::register_*() Generate exception if ID is registered (Jaroslav Rohel)
- [3fc9235d] [microdnf] Sync with ArgParser changes (use register_* methods) (Jaroslav Rohel)
- [f3ff457a] [argparser] Rename methods to fit functionality/description (Jaroslav Rohel)
- [a191ce0a] [argparser] Make argument constructors and some methods private. (Jaroslav Rohel)
- [d4d09cdd] [argparser] Add documentation strings (Jaroslav Rohel)
- [13d98151] [argparser] Add reference to ArgumentParser (Jaroslav Rohel)
- [fec19436] [argparser] Test that all required positional arguments are present (Jaroslav Rohel)
- [321d5fc5] [microdnf] Sync with ArgParser changes (Jaroslav Rohel)
- [0ab21195] [argparser] Readibility: Renaming (Jaroslav Rohel)
- [cbe89a3a] [argparser] Throw exception if unknown argument (Jaroslav Rohel)
- [b3d112a8] [argparser] Value of positional argument cannot start with '-' character (Jaroslav Rohel)
- [15ceeb03] [argparser] Fix: Set "used" if argument was recognised as positional (Jaroslav Rohel)
- [2be9f198] [argparser] Define and use libdnf style exceptions (Jaroslav Rohel)
- [f48fdb3a] [microdnf] Use ArgParser from libdnf-cli (Jaroslav Rohel)
- [da66e8fc] [argparser] Move from microdnf to libdnf-cli (Jaroslav Rohel)
- [2e36c692] [argparser] Readibility changes (clang-tidy) (Jaroslav Rohel)
- [c99f92f7] [microdnf] Sync with ArgParser changes (Jaroslav Rohel)
- [5e876370] [argparser] Add setters/getters, all data members private, pass by value (Jaroslav Rohel)
- [c447f756] Add test for Goal class (Jaroslav Mracek)
- [8617ee5c] Add bindings for Goal class (Jaroslav Mracek)
- [522271cb] Add Goal class (Jaroslav Mracek)
- [434b605a] microdnf: Fix progressbar to show 0 elapsed seconds for skipped packages. (Daniel Mach)
- [ea717e98] progressbar: Change MultiProgressBar state after its ticks are updated (Daniel Mach)
- [fb22757d] progressbar: Round the elapsed seconds (Daniel Mach)
- [3fa1ea1b] tests: Fix memory leak in test_solv_query.t (Daniel Mach)
- [4927916c] tests: Mark IdQueueTest::test_iterator_performance() as a performance test (Daniel Mach)
- [1cf99fff] build: Rework sanitizers again, use LD_PRELOAD in the tests (Daniel Mach)
- [453670b1] bindings: Disable 'maybe-uninitialized' warnings in swig bindings (Daniel Mach)
- [14c18fc2] tests: Improve performance by sharing solv cache among tests in a class (Daniel Mach)
- [6f52a3e1] [dnf5] libdnf::cli::output implementation of libsmartcols (Nicola Sella)
- [80dd7c6a] Remove (not working) static asan linking, add compiler flag (Aleš Matěj)
- [8df940a2] tests: Flags have to be bitwise ORed, using AND doesn't set any (Aleš Matěj)
- [0ad2d6a3] tests: Do not create new solv and repo sacks, use those from base (Aleš Matěj)
- [e56a825e] fix memory leak when debugging, free even on success (Aleš Matěj)
- [d066b6bd] Move is_file_pattern to libdnf::utils::utils_internal.hpp (Jaroslav Mracek)
- [b1b3e849] Rename SolvQuery::ifilter_reponame to SolvQuery::ifilter_repoid (Jaroslav Mracek)
- [6ca59462] Move SolvQuery::Impl into solv_query_impl.hpp (Jaroslav Mracek)
- [6ba10ce2] Mark method as const (Jaroslav Mracek)
- [7630e81c] Add empty method for SolvQuery (Jaroslav Mracek)
- [48719e3a] Add move constructor for SolvMap (Jaroslav Mracek)
- [f5598638] Add ifilters for SolvQuery (Jaroslav Mracek)
- [a9bbd743] [dnf5] fix number of packages in unit tests (Jaroslav Rohel)
- [c280c0a9] [dnfdaemon] Conditionally build dnfdaemon tests (Marek Blaha)
- [f872d473] [dnfdaemon] Use constants instead of string literals (Marek Blaha)
- [e4403c82] [dnfdaemon] Fix logging and get object_path from session (Marek Blaha)
- [a68a6703] [dnfdaemon] Rename files to snake_case, clang-format (Marek Blaha)
- [a14f43cf] [dnfdaemon] Test for RepoConf service (Marek Blaha)
- [685ed399] [dnfdaemon] More generic RepoConf.list() signature (Marek Blaha)
- [6f661d5f] [dnfdaemon] Fix the installroot session configuration option (Marek Blaha)
- [a68df437] [dnfdaemon] Add dbus and polkit configuration files (Marek Blaha)
- [6da2e278] [dnfdaemon] Initial commit (Marek Blaha)
- [01ef45ec] [microdnf] Context::load_rpm_repos: multithread support (Jaroslav Rohel)
- [868572e0] [microdnf] add Threads library to linker (Jaroslav Rohel)
- [6f149000] [microdnf] Add Context::load_rpm_repos() (Jaroslav Rohel)
- [23c9e230] [microdnf] Use rpm::Transaction callbacks with progressbars (Jaroslav Rohel)
- [07213f04] [microdnf] Fix output after completing bars (Daniel Mach)
- [21462da1] [microdnf] PkgDownloadCB class: update progress bar state (Jaroslav Rohel)
- [b93cef8b] [microdnf] PkgDownloadCB class: Use progress bar from libdnf::cli (Jaroslav Rohel)
- [52d28287] [microdnf] add command download (Jaroslav Rohel)
- [c6935703] [microdnf] download_packages() (Jaroslav Rohel)
- [4c6aded3] [microdnf] Add commands install, reinstall, remove, upgrade (Jaroslav Rohel)
- [2e3d6b89] [microdnf] Set "cachedir" for root user (Jaroslav Rohel)
- [fcec8842] [microdnf] repoquery: Use rpm::SolvQuery::resolve_pkg_spec() (Jaroslav Rohel)
- [576cc4db] [microdnf] Support "--setopt=KEY=VALUE" (Jaroslav Rohel)
- [0a330caa] [microdnf] Use argument parser help support (Jaroslav Rohel)
- [ae6743ff] [argument parser] Start help support (Jaroslav Rohel)
- [9d12cf7a] [microdnf] Register "repoquery" command (Jaroslav Rohel)
- [9fe9a1ad] [microdnf] Basic implementation of "repoquery" command (Jaroslav Rohel)
- [2132f009] [microdnf] Register "repolist" command (Jaroslav Rohel)
- [c4b92342] [microdnf] Implmement "repolist" command (Jaroslav Rohel)
- [e78ce1e2] [microdnf] Use Context, parse arguments, set and use command (Jaroslav Rohel)
- [4ef5bc3c] [microdnf] Set path to user cache directory (Jaroslav Rohel)
- [7c3f6a8f] [microdnf] Context: Add support for repository loading (Jaroslav Rohel)
- [cfd90dda] [microdnf] Add Context class (Jaroslav Rohel)
- [441e1337] [microdnf] Add Command base class (Jaroslav Rohel)
- [5640e7cb] [microdnf] Load configurations, detect arch and os release (Jaroslav Rohel)
- [822d2d13] [microdnf] Determine log directory and set StreamLogger (Jaroslav Rohel)
- [4e476e4a] [microdnf] - add Base and set MemoryBufferLogger (Jaroslav Rohel)
- [4b6028d0] [argument parser] Implementation (Jaroslav Rohel)
- [8f0b5eee] [microdnf] Add utils to detect architecture, base arch, and system release (Jaroslav Rohel)
- [ee131e36] [microdnf] utils: xdg get user directories (Jaroslav Rohel)
- [cfddb521] [microdnf] Add utils with am_i_root() (Jaroslav Rohel)
- [2ea91269] rpm::Transaction class: implement interface to librpm transaction (Jaroslav Rohel)
- [3f347b00] sqlite3: apply clang-tidy and clang-format (Daniel Mach)
- [fdb21c08] sqlite3: Fix compilation issues (Daniel Mach)
- [ae252d87] sqlite3: Move code to the new location (Daniel Mach)
- [9e47ea51] tests: Add tests for libdnf::rpm::Package (Lukáš Hrázký)
- [f0679332] test/libdnf/rpm: Add a script to generate repodata (Lukáš Hrázký)
- [2923eace] test/libdnf/rpm: Add a repo with a package with baseurl (Lukáš Hrázký)
- [897b7988] test/libdnf/rpm: Add packages for the Package class unittests (Lukáš Hrázký)
- [2311ed1a] test/libdnf/rpm/test_solv_query: Fix some of the CPPUNIT_ASSERT macros (Lukáš Hrázký)
- [0ef2ffde] test/libdnf/rpm: Add source rpms to the testing repo (Lukáš Hrázký)
- [ee72833a] tests: Add a class enabling std collection assertions (Lukáš Hrázký)
- [bfa28799] tests: Create RepoFixture to share the code for repository setup (Lukáš Hrázký)
- [bcc76753] rpm/solv_sack: Add dump_debugdata() (Lukáš Hrázký)
- [c578503a] rpm/package: Comment out Package::get_build_host() (Lukáš Hrázký)
- [3b1a3d5e] rpm/package: Call the correct metod for get_requires() (Lukáš Hrázký)
- [1d2e0d4b] rpm/checksum: Fix construction with a nullptr (Lukáš Hrázký)
- [835a2302] utils::fs: Replace old implementation (Daniel Mach)
- [bd7f65d8] utils::string: Replace old implementation (Daniel Mach)
- [91a1975a] Fix difference_type in PackageSet and ReldepList iterators (Daniel Mach)
- [19f8677b] cli: Progressbar implementation (Daniel Mach)
- [07d9b8ae] cli: Add libdnf::cli::utils::tty for handling terminal (Daniel Mach)
- [41b8355f] Add license headers to libdnf::cli::utils::utf8 (Daniel Mach)
- [e93ea3de] cli: Rename libdnf_cli::utils::utf8 namespace to libdnf::cli::utils::utf8 (Daniel Mach)
- [84a0299c] rpm::Package::get_local_filepath() (Jaroslav Rohel)
- [e98e3b55] rpm::Package::get_rpmdbid(): mark as const (Jaroslav Rohel)
- [dc319e7a] rpm::Package::get_repo() method (Jaroslav Rohel)
- [5155777a] Add tests for SolvQuery::resolve_pkg_spec() with glob and icase (Jaroslav Rohel)
- [4ed5cfd2] Fix SolvQuery::Impl::filter_nevra() IGLOB support (Jaroslav Rohel)
- [939397a4] Fix SolvQuery.ifilter_version() and release (Jaroslav Mracek)
- [665a3cfc] SWIG: declare pid_t and time_t types (Jaroslav Rohel)
- [8099c22d] Reduce count of arguments in internal function (Jaroslav Mracek)
- [894136d1] Add description for an internal function (Jaroslav Mracek)
- [06e6f71d] Remove unneeded conversion to int (Jaroslav Mracek)
- [50a4c3dc] Rename a method argument to more convenient name (Jaroslav Mracek)
- [6b36ada2] [clang] Add changes proposed by clang (Jaroslav Mracek)
- [d8810ca1] Move hy_is_glob_pattern to libdnf::utils::is_glob pattern() (Jaroslav Mracek)
- [6fcc0ddb] Rename SolvQuery.subject_solution to resolve_pkg_spec (Jaroslav Mracek)
- [6e673a66] Replace duplicated code by a function (Jaroslav Mracek)
- [97e3523c] Add unittest (NEVRA glob, icase) for SolvQuery.subject_solution() (Jaroslav Mracek)
- [b4d64acf] Add with_src argument for SolvQuery.subject_solution (Jaroslav Mracek)
- [d93e2110] Make work SolvQuery.subject_solution when query is not full (Jaroslav Mracek)
- [67cd2c20] Add unittest for SolvQuery.subject_solution() (Jaroslav Mracek)
- [20a538de] Fix SolvQuery.ifilter_nevra() (Jaroslav Mracek)
- [08e82e13] Add temporal code to allow a build with bindings (Jaroslav Mracek)
- [cd0103d6] Add SolvQuery::subject_solution (Jaroslav Mracek)
- [c854efaa] Add suppors ICASE for SolvQuery.ifilter_nevra() (Jaroslav Mracek)
- [a9d9c11c] Add Nevra::PKG_SPEC_FORMS (Jaroslav Mracek)
- [80f65f56] Performance improvement when "*" argument is used (Jaroslav Mracek)
- [37e0630c] Add ifilter_nevra for Nevra struct (Jaroslav Mracek)
- [55035977] Add ifilter_epoch for strings in SolvQuery (Jaroslav Mracek)
- [51e1bc0f] Add rubygem-test-unit into build requirements (Pavla Kratochvilova)
- [33b09400] tests: Add unittests for ReldepList (Aleš Matěj)
- [e03835c5] Add ReldepList iterator by wrapping IdQueue iterator (Aleš Matěj)
- [c1230b88] Add Reldep move constructor needed for ReldepList iterator (Aleš Matěj)
- [1545f64e] tests: Add unittests for IdQueue iterator (Aleš Matěj)
- [7d4edcaa] Add IdQueue iterator (Aleš Matěj)
- [c4720f79] tests: Add unittests for Reldep (Aleš Matěj)
- [56c1494b] unittests: First SWIG Perl bindings tests (Jaroslav Rohel)
- [7e59e19f] unittests: First SWIG Ruby bindings tests (Jaroslav Rohel)
- [94c19891] unittests: First SWIG Python bindings tests (Jaroslav Rohel)
- [7dd20eb8] SWIG: added bindings (Jaroslav Rohel)
- [03e9f4f4] PreserveOrderMap: mark operator*() as const, add erase(iterator pos) (Jaroslav Rohel)
- [633a2df4] Fix: rpm::SolvSack::Impl::~Impl(): Detach repositories before pool_free() (Jaroslav Rohel)
- [67a7b78d] Fix: WeakPtr: memory leak in operator=(WeakPtr && src) (Jaroslav Rohel)
- [cf161b53] cli: Optimize MB_CUR_MAX usage in utf8 handling functions (Daniel Mach)
- [4129b86f] utils: Cast mbrtowc() result to signed int, because it can return -1 (Daniel Mach)
- [feeebad5] tests: Use installroot, replace relative paths with PROJECT_SOURCE_DIR (Daniel Mach)
- [41d070a8] sack: Set installroot according to the configuration (Daniel Mach)
- [f08b8f52] utils: Add TempDir class for managing a temp directory (Daniel Mach)
- [7481726d] Remove 'static' from tests to make setUp() and tearDown() working (Daniel Mach)
- [7bef4425] Remove temporal variables (Jaroslav Mracek)
- [625ea2b5] Add changes recommended by clang (Jaroslav Mracek)
- [d3571cfa] Add doc strings for Nevra (Jaroslav Mracek)
- [e2c74765] Add unittests for Nevra struct (Jaroslav Mracek)
- [efe58768] Allow globs in epoch when parsing NEVRAs (Jaroslav Mracek)
- [fc3363e8] Handle EPOCH as string in Nevra struct (Jaroslav Mracek)
- [cfaf05b3] Add Nevra struct (Jaroslav Mracek)
- [d49d3d62] [logger] Rename write(level, message) to log(level, message) (Jaroslav Rohel)
- [a5ec0160] Provide a minor performance optimization (Jaroslav Mracek)
- [e12d973b] Add unittests for SolvQuery (Jaroslav Mracek)
- [b2736a23] [Minor] Fix some issues reported by clang (Jaroslav Mracek)
- [475cedc0] Add const to parameters that should be const (Jaroslav Mracek)
- [81374299] Add ifilter for SolvQuery (Jaroslav Mracek)
- [b386851e] Add ifilters for SolvQuery (Jaroslav Mracek)
- [1199a6da] Add ifilter_provides() for SolvQuery (Jaroslav Mracek)
- [596c106b] Replace Queue by IdQueue (Jaroslav Mracek)
- [8006fc25] Fixed generation of bindings. (KOLANICH)
- [bfa08da3] Fix: rpm::PackageSetIterator: remove duplicate and badly synced current_value (Jaroslav Rohel)
- [ccbd74e6] rpm::solv::SolvMapIterator::begin() point to the first element or end() (Jaroslav Rohel)
- [491556a7] Fix: rpm::PackageSetIterator and rpm::solv::SolvMapIterator copy constructor (Jaroslav Rohel)
- [d373ef85] Fixed installation of python bindings (KOLANICH)
- [ecce8b01] Add minor changes according to preferred style and clang (Jaroslav Mracek)
- [c4d1ba18] Use empty method in make_provides_ready() (Jaroslav Mracek)
- [a269af55] Add empty() for IdQueue (Jaroslav Mracek)
- [5c5f928e] Add minor changes according to preferred style (Jaroslav Mracek)
- [1ac661bb] Improve internalize of libsolv repos (Jaroslav Mracek)
- [ba0ea499] Replace Queue by IdQueue (Jaroslav Mracek)
- [749a14e6] Remove unnecessary test (Jaroslav Mracek)
- [ce00aaa8] Replace Queue and Map by c++ wrappers (Jaroslav Mracek)
- [ad6db7ab] Move unsafe methods in public part (Jaroslav Mracek)
- [9993c41b] Add make_provides_ready method (Jaroslav Mracek)
- [2442d262] Remove redundant argument from load_system_repo() (Jaroslav Mracek)
- [e58dffec] Use build_cache from RepoConf for repo_load (Jaroslav Mracek)
- [32f19b9c] Add repo conf option build_cache (Jaroslav Mracek)
- [e7138d0b] Fix missing declaration of move constructors in SolvQuery (Jaroslav Mracek)
- [5c94b1aa] Replace SolvSack by SolvSackWeakPtr in SolvQuery (Jaroslav Mracek)
- [014a6f80] Add missing fmt requirement to spec file (Marek Blaha)
- [63e05b23] Do not use inline for a large function and removal of noexcept (Jaroslav Mracek)
- [09add899] Remove unneeded namespace prefix (Jaroslav Mracek)
- [5e724332] Add code that disappeared during rebase (Jaroslav Mracek)
- [75696124] Add unittests for SolvQuery (Jaroslav Mracek)
- [97551678] Rename id_map query_result in SolvQuery (Jaroslav Mracek)
- [093f019e] Strip epoch by a way like libsolv (Jaroslav Mracek)
- [70cd3dc2] Rename SolvQuery.ifilter_nevra_strict (Jaroslav Mracek)
- [b0091778] Do not create new pool id for evr during NEVRA parsing (Jaroslav Mracek)
- [61de8327] [dnf5] Do not create new id in pool in ifilter_evr() (Jaroslav Mracek)
- [a71beda4] [dnf5] Add get_full_nevra for Package class (Jaroslav Mracek)
- [74d9296b] [dnf5] Add unittest for SolvQuery.ifilter_name (Jaroslav Mracek)
- [87bd1c1b] [dnf5] Add default destructor for SolvQuery (Jaroslav Mracek)
- [d9776835] Add get_packageset() method for SolvQuery (Jaroslav Mracek)
- [bb4719ef] [dnf5] Add method size for SolvQuery (Jaroslav Mracek)
- [3c6de488] [dnf5] Changes required by rebase (Jaroslav Mracek)
- [59eaef5a] [dnf5] Add ifilter for SolvQuery + format (clang) changes (Jaroslav Mracek)
- [34e7a347] [dnf5] Replace part of the code by template (Jaroslav Mracek)
- [1359d7b7] [dnf5] Replace if by switch plus clang changes (Jaroslav Mracek)
- [0f93a399] [dnf5] Add additional ifilters for SolvQuery (Jaroslav Mracek)
- [f85be8b6] [dnf5] Rename class Query to SolvQuery (Jaroslav Mracek)
- [e6ba02e4] [dnf5] Add ifilters for SolvQuery (Jaroslav Mracek)
- [46842f2d] [dnf5] Rename files according to class name (Jaroslav Mracek)
- [32714522] [dnf5] Use PackageId in SolvMap (Jaroslav Mracek)
- [c52721e6] [dnf5] Add rpm query class with first filters (Jaroslav Mracek)
- [55ff8204] [dnf5] iniparser: Add unit tests (Jaroslav Rohel)
- [3ee26b4a] [dnf5] Fix: iniparser: raw_item and new line character at end of file (Jaroslav Rohel)
- [27b27c41] [dnf5] iniparser: Use empty() instead of length()==0 (Jaroslav Rohel)
- [73ff97e5] [dnf5] Fix: iniparser: Parsing empty lines (Jaroslav Rohel)
- [2f9bee3b] [dnf5] rpm::PackageSet: use rpm::SolvSackWeakPtr (Jaroslav Rohel)
- [4a48b414] [dnf5] rpm::Reldep: use rpm::SolvSackWeakPtr (Jaroslav Rohel)
- [719f7328] [dnf5] rpm::Reldep: Remove useless methods, clean code (Jaroslav Rohel)
- [881a003d] [dnf5] rpm::ReldepList: use rpm::SolvSackWeakPtr (Jaroslav Rohel)
- [09cbffa3] [dnf5] rpm::Package: use rpm::SolvSackWeakPtr (Jaroslav Rohel)
- [a01f571b] [dnf5] rpm::SolvSackWeakPtr: WeakPtr support to rpm::SolvSack (Jaroslav Rohel)
- [c621986e] [dnf5] Unit tests for WeakPtrGuard methods empty(), size(), clear() (Jaroslav Rohel)
- [dbf26152] [dnf5] fix: WeakPtrGuard::clear() Remove/unregister invalidated WeakPtrs (Jaroslav Rohel)
- [249c9833] [dnf5] rpm::RepoSack: Creating repositories according to config files (Jaroslav Rohel)
- [708bee49] [dnf5] Base: Load conf files from dir in alphabetical order (Jaroslav Rohel)
- [34860f7e] [dnf5] Base: Add methods for loading of main configuration from files in dir (Jaroslav Rohel)
- [158bac46] [dnf5] Base: Add methods for loading of main configuration from file (Jaroslav Rohel)
- [185509e1] [dnf5] unit test: rpm::SolvSack load system repository (Jaroslav Rohel)
- [b2a888a3] [dnf5] rpm::SolvSack load system repository (Jaroslav Rohel)
- [4f8ca758] [dnf5] rpm::RepoSack::new_repo(): Only "available" repo can be created (Jaroslav Rohel)
- [2af52b06] [dnf5] Base: Add variables map (Jaroslav Rohel)
- [3fd46e61] [dnf5] Add rpm_solv_sack into Base (Jaroslav Rohel)
- [433fa44a] [dnf5] Add rpm_repo_sack into Base (Jaroslav Rohel)
- [c7595ce1] [dnf5] Base: fix includes (Jaroslav Rohel)
- [3cc93872] [microdnf] CMakeList: Fix: Use of found source files (Jaroslav Rohel)
- [b034d1be] [dnf5] RepoQuery: Extend ifilter_id(), add ifilter_name() (Jaroslav Rohel)
- [a5d45254] [dnf5] Query: Optimize: Remove calculation of unused value (Jaroslav Rohel)
- [41d4419e] [dnf5] Pass logger arg to MemoryBufferLogger::write_to_logger() as reference (Jaroslav Rohel)
- [8fe8c502] [dnf5] solv_cache: use filesystem::path for concatenate path components (Jaroslav Rohel)
- [be503de2] [dnf5] Remove repodata states,ids from LibsolvRepoExt, SolvSack::load_repo() (Jaroslav Rohel)
- [a04630cb] [dnf5] Rename files sack* to solv_sack* (Jaroslav Rohel)
- [f0d30963] [dnf5] Rename rpm::Sack to rpm::SolvSack (Jaroslav Rohel)
- [894e1f7d] [dnf5] Add unit tests for loading repository into rpm::Sack (Jaroslav Rohel)
- [3306133b] [dnf5] remove hard-coded nsolvables, use real repodata in tests for package set (Jaroslav Rohel)
- [bfe43b20] [dnf5] unit test for package set: compilable with rpm::Sack changes (Jaroslav Rohel)
- [a338c6ff] [dnf5] unit test for package set: use unique_ptr (Jaroslav Rohel)
- [72dc7433] [dnf5] unit tests: Add testing repository dnf-ci-fedora (Jaroslav Rohel)
- [868fd7bb] [dnf5] Sack load repo (Jaroslav Rohel)
- [34015fb1] [dnf5] Add unit test for rpm::RepoQuery and rpm::RepoSack (Jaroslav Rohel)
- [5d209c24] [dnf5] Implement rpm RepoSack (Jaroslav Rohel)
- [0f679603] [dnf5] Implement rpm RepoQuery (Jaroslav Rohel)
- [9c8221aa] [dnf5] Add main configuration into Base class (Jaroslav Rohel)
- [cddcd786] [dnf5] Modify rpm repository support (rpm::Repo) for new libdnf (Jaroslav Rohel)
- [f0ff513f] [dnf5] Add utils - have_files_same_content_noexcept function (Jaroslav Rohel)
- [af4275be] [dnf5] Move rpm repository support to new location (Jaroslav Rohel)
- [fff90405] [dnf5] cmake: Add GLib2, GPGme, and librepo libraries (Jaroslav Rohel)
- [162e33a6] [dnf5] cmake: set gettext domain for translations (Jaroslav Rohel)
- [d8fe8799] [dnf5] Move bgettext to the new location (Jaroslav Rohel)
- [6e6f932d] [dnf5] Modify ConfigRepo for new libdnf (Jaroslav Rohel)
- [41000b03] [dnf5] Move ConfigRepo to the new location (Jaroslav Rohel)
- [aca7d88d] [dnf5] Modify ConfigMain for new libdnf (Jaroslav Rohel)
- [e9c09e68] [dnf5] Move ConfigMain to the new location (Jaroslav Rohel)
- [e994d534] [dnf5] Modify Config for new libdnf - (license, snake_case) (Jaroslav Rohel)
- [eeebcc6f] [dnf5] Move Config to the new location (Jaroslav Rohel)
- [0619ca88] [dnf5] Modify OptionBinds for new libdnf (Jaroslav Rohel)
- [6f0bdf06] [dnf5] Move OptionBinds to the new location (Jaroslav Rohel)
- [ab4e1e56] [dnf5] Add dependency on fmt library - for text formating (Jaroslav Rohel)
- [b74cdf3d] [dnf5] Options: Make test(), from_string(), and to_string() public (Jaroslav Rohel)
- [758ad125] cli: Helper functions for working with utf-8 strings (Daniel Mach)
- [a7b533d8] test: Fix cmake configuration for libdnf_cli tests (Daniel Mach)
- [593d0d6f] sack: add missing sack.cpp (Daniel Mach)
- [ddf73f1d] [dnf5] Add common Sack (Jaroslav Rohel)
- [e78099ad] [dnf5] Example query implementation based on sack::Query with unit test (Jaroslav Rohel)
- [83ad4253] [dnf5] Add Query support (Jaroslav Rohel)
- [86931dc1] tests: Turn unused-comparison and unused-value warnings off (Daniel Mach)
- [d95df4e1] Implement PackageSet::iterator. (Daniel Mach)
- [39387872] Move part of PackageSet's private implementation to MapSolv class (Daniel Mach)
- [710e8e8f] Add project dir to includes (Daniel Mach)
- [600ebf19] PackageSet: document references to the dnf4 code (Daniel Mach)
- [2a46e271] Change PackageSet operators according to Python set operations (Daniel Mach)
- [f5e484b3] Fix PackageSet compilation errors (Daniel Mach)
- [0f88bb66] Run clang-tidy and clang-format on PackageSet (Daniel Mach)
- [82364455] Move PackageSet to the new location (Daniel Mach)
- [fb2ffe83] Print test duration times (Daniel Mach)
- [5a07b9d1] Introduce performance testing for libdnf (Daniel Mach)
- [f3203116] [dnf5] Modify ConfigParser for new libdnf (Jaroslav Rohel)
- [261e0894] [dnf5] Move ConfigParser from old libdnf (Jaroslav Rohel)
- [dbe446b8] [dnf5] Modify PreserveOrderMap for new libdnf (Jaroslav Rohel)
- [29c2bd3e] [dnf5] Move PreserveOrderMap from old libdnf (Jaroslav Rohel)
- [40ea4ed4] [dnf5] Modify iniparser for new libdnf (Jaroslav Rohel)
- [e3f29148] [dnf5] Move IniParser from old libdnf (Jaroslav Rohel)
- [bfb7d7a0] [dnf5] Change return value of to_string method (Jaroslav Mracek)
- [51070b2f] [dnf5] Add changes according to clang recommendation (Jaroslav Mracek)
- [8fb8d8d8] [dnf5] Rename Reldep::ComparisonType to CmpType (Jaroslav Mracek)
- [38b64d3e] Add tests for IdQueue (Jaroslav Mracek)
- [f119535e] Add unittest for ReldepParser (Jaroslav Mracek)
- [c704d98b] fixup! [dnf5] Make reldep parser faster (Jaroslav Mracek)
- [71ce72cd] [dnf5] Make reldep parser faster (Jaroslav Mracek)
- [fc565df8] [dnf5] Add method and operators for IdQueue (Jaroslav Mracek)
- [8119b04a] [dnf5] Change operator= of ReldepList (Jaroslav Mracek)
- [22906fe6] [dnf5] Add checksum getters for Package class (Jaroslav Mracek)
- [225f0229] [dnf5] Add additional methods to Package class (Jaroslav Mracek)
- [443a05eb] [dnf5] Rename and refactor Dependency and DependencyContainer (Jaroslav Mracek)
- [2e0d1757] [dnf5] Move IdQueue from dnf4 with minnor changes (Jaroslav Mracek)
- [3da50492] Move Dependency structures from dnf4 directory (Jaroslav Mracek)
- [f277ad75] Add type test for Ids (Jaroslav Mracek)
- [ab1bd863] [dnf5] Create a Package class with first functions (Jaroslav Mracek)
- [c7bca073] [dnf5] Create a dummy Sack class (Jaroslav Mracek)
- [4294d373] [dnf5] Modify option support for new libdnf (Jaroslav Rohel)
- [7ffee5f2] [dnf5] Move options support to the new location (Jaroslav Rohel)
- [7e45f0ad] spec: Fix BuildRequires related to sphinx (Daniel Mach)
- [49354b03] doc: Fix building html (Daniel Mach)
- [6f496de0] [dnf5] Add unit tests for WeakPtr (Jaroslav Rohel)
- [bfc6c206] [dnf5] WeakPtr implementation (Jaroslav Rohel)
- [7c6e8e69] [dnf5] Add unit tests for Set (Jaroslav Rohel)
- [50f850ce] [dnf5] Add Set class (Jaroslav Rohel)
- [a34e6874] [dnf5] Unittest for Logger: Test swap_logger() and get_loggers_count() (Jaroslav Rohel)
- [9e18cbb6] [dnf5] Add LogRouter::get_loggers_count() method (Jaroslav Rohel)
- [adf8ba4a] [dnf5] Add LogRouter::swap_logger() method (Jaroslav Rohel)
- [b440d01f] [dnf5] Add base exception support (Jaroslav Rohel)
- [188cdbc9] [dnf5] Add LogRouter into Base class (Jaroslav Rohel)
- [40e6b9b3] [dnf5] Remove code that was replaced by new Logger (Jaroslav Rohel)
- [77f56862] [dnf5] @replace comments for Logger implementation (Jaroslav Rohel)
- [3102e83c] [dnf5] Add unit test for loggers (Jaroslav Rohel)
- [9ddadd11] [dnf5] Add StreamLogger - logs messages into stream (Jaroslav Rohel)
- [aed2f08c] [dnf5] Add LogRouter - forwards messages to several loggers (Jaroslav Rohel)
- [9e86732c] [dnf5] Add MemoryBufferLogger - logs into memory buffer (Jaroslav Rohel)
- [8febb881] [dnf5] Add NullLogger - logger that discards all incoming log messages (Jaroslav Rohel)
- [017d2de1] [dnf5] Add Logger - abstract interface for logging (Jaroslav Rohel)
- [17024f86] [dnf5] Add empty Base class (Jaroslav Rohel)
- [a9f47f90] Import a new project template (Daniel Mach)
- [6d812e72] Move all existing code under 'dnf-4' directory (Daniel Mach)
- [ad8e1fed] Reset active modules when no module enabled or default (RhBug:1767351) (Jaroslav Mracek)